using System;
using System.Data;
using System.Data.Odbc;
using System.Configuration;
using System.Collections.Generic;

public partial class OdpovedDAL
{
    public static List<Odpoved> SelectByInstanciaIdOtazkaId( int instanciaId, int otazkaId )
    {
        List<Odpoved> odpovedList = new List<Odpoved>();
        Odpoved odpoved;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.odpoved WHERE instancia_ankety_id = ? AND otazka_id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@instancia_ankety_id", OdbcType.Int).Value = instanciaId;
             odbcCommand.Parameters.Add("@otazka_id", OdbcType.Int).Value = otazkaId;

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 while ( odbcDataReader.Read() )
                 {
                     odpoved = new Odpoved();

                     odpoved.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                     odpovedList.Add( odpoved );
                 }

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return odpovedList;
    }

    public static List<Odpoved> SelectByInstanciaIdOsobaId( int instanciaId, int osobaId )
    {
        List<Odpoved> odpovedList = new List<Odpoved>();
        Odpoved odpoved;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.odpoved WHERE instancia_ankety_id = ? AND osoba_id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@instancia_ankety_id", OdbcType.Int).Value = instanciaId;
             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = osobaId;

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 while ( odbcDataReader.Read() )
                 {
                     odpoved = new Odpoved();

                     odpoved.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                     odpovedList.Add( odpoved );
                 }

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return odpovedList;
    }

    public static Odpoved SelectByInstanciaIdOsobaIdOtazkaId( int instanciaId, int osobaId, int otazkaId )
    {
        Odpoved odpoved;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.odpoved WHERE instancia_ankety_id = ? AND osoba_id = ? AND otazka_id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@instancia_ankety_id", OdbcType.Int).Value = instanciaId;
             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = osobaId;
             odbcCommand.Parameters.Add("@otazka_id", OdbcType.Int).Value = otazkaId;

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 if( !odbcDataReader.Read() )
                 {
                     odbcDataReader.Close();
                     odbcConnection.Close();

                     return null;
                 }

                 odpoved = new Odpoved();

                 odpoved.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return odpoved;
    }

    public static List<Odpoved> DistinctInstanciaIdByOsobaId( int instanciaId )
    {
        List<Odpoved> odpovedList = new List<Odpoved>();
        Odpoved odpoved;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT DISTINCT ON(osoba_id) * FROM alumni.odpoved WHERE instancia_ankety_id = ?", odbcConnection );
  
             odbcCommand.Parameters.Add("@instancia_ankety_id", OdbcType.Int).Value = instanciaId;

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 while ( odbcDataReader.Read() )
                 {
                     odpoved = new Odpoved();

                     odpoved.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                     odpovedList.Add( odpoved );
                 }

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return odpovedList;
    }

    public static int DistinctCountInstanciaIdByOsobaId( int instanciaId )
    {
        int rowCount;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT COUNT(DISTINCT osoba_id) FROM alumni.odpoved WHERE instancia_ankety_id = ?", odbcConnection );
  
             odbcCommand.Parameters.Add("@instancia_ankety_id", OdbcType.Int).Value = instanciaId;

             odbcConnection.Open();

             rowCount = Convert.ToInt32( odbcCommand.ExecuteScalar() );

             odbcConnection.Close();
        }

        return rowCount;
    }

    public static int SelectCountByInstanciaIdOsobaId( int instanciaId, int osobaId )
    {
        int rowCount;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand("SELECT COUNT(*) FROM alumni.odpoved WHERE instancia_ankety_id = ? AND osoba_id = ?", odbcConnection);

             odbcCommand.Parameters.Add("@instancia_ankety_id", OdbcType.Int).Value = instanciaId;
             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = osobaId;

             odbcConnection.Open();

             rowCount = Convert.ToInt32( odbcCommand.ExecuteScalar() );

             odbcConnection.Close();
        }

        return rowCount;
    }
}
