using System;
using System.Data;
using System.Data.Odbc;
using System.Configuration;
using System.Collections.Generic;
using System.Web;

public partial class OsobaDAL
{
    public static Osoba SelectByKonto( string konto )
    {
        Osoba osoba;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.osoba WHERE konto = ?", odbcConnection );

             odbcCommand.Parameters.Add("@konto", OdbcType.NVarChar).Value = konto;

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 if( !odbcDataReader.Read() )
                 {
                     odbcDataReader.Close();
                     odbcConnection.Close();

                     return null;
                 }

                 osoba = new Osoba();

                 osoba.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return osoba;
    }

    public static Osoba SelectByEmail( string email )
    {
        Osoba osoba;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.osoba WHERE email = ?", odbcConnection );

             odbcCommand.Parameters.Add("@email", OdbcType.NVarChar).Value = email;

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 if( !odbcDataReader.Read() )
                 {
                     odbcDataReader.Close();
                     odbcConnection.Close();

                     return null;
                 }

                 osoba = new Osoba();

                 osoba.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return osoba;
    }

    public static List<Osoba> SelectByTypOsobyId( int typOsobyId )
    {
        List<Osoba> osobaList = new List<Osoba>();
        Osoba osoba;
        int id;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.osoba WHERE typ_osoby_id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@typ_osoby_id", OdbcType.Int).Value = typOsobyId;
 
             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 while ( odbcDataReader.Read() )
                 {
                     id = odbcDataReader.GetInt32(0);

                     osoba = (Osoba)HttpContext.Current.Cache["Osoba_" + id.ToString()];

                     if( osoba == null )
                     {
                         osoba = new Osoba();

                         osoba.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                         HttpContext.Current.Cache["Osoba_" + id.ToString()] = osoba;
                     }

                     osobaList.Add( osoba );
                 }

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return osobaList;
    }

    public static int SelectCountByTypOsobyId( int typOsobyId )
    {
        int rowCount;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT COUNT(*) FROM alumni.osoba WHERE typ_osoby_id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@typ_osoby_id", OdbcType.Int).Value = typOsobyId;

             odbcConnection.Open();

             rowCount = Convert.ToInt32( odbcCommand.ExecuteScalar() );

             odbcConnection.Close();
        }

        return rowCount;
    }

    public static List<int> SelectGraduationYears()
    {
        List<Osoba> osobaList = new List<Osoba>();
        List<int> graduationYears = new List<int>();
        Osoba osoba;
        int id;

        using (OdbcConnection odbcConnection = new OdbcConnection(ConfigurationManager.ConnectionStrings["alumni"].ConnectionString))
        {
            OdbcCommand odbcCommand = new OdbcCommand("SELECT DISTINCT ON (rok_absolvovania) rok_absolvovania FROM alumni.osoba WHERE typ_osoby_id=2 AND rok_absolvovania > 0", odbcConnection);

            odbcConnection.Open();

            using (OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader())
            {
                while (odbcDataReader.Read())
                {
                    id = odbcDataReader.GetInt32(0);

                    osoba = (Osoba)HttpContext.Current.Cache["Osoba_" + id.ToString()];

                    graduationYears.Add(odbcDataReader.GetInt32(0));
                }

                odbcDataReader.Close();
            }

            odbcConnection.Close();
        }

        return graduationYears;
    }


    public static Osoba SelectIdByKonto(string konto, bool aktivne)
    {
        Osoba osoba;

        using (OdbcConnection odbcConnection = new OdbcConnection(ConfigurationManager.ConnectionStrings["alumni"].ConnectionString))
        {
            OdbcCommand odbcCommand = new OdbcCommand("SELECT id FROM alumni.osoba WHERE konto = ? AND konto_aktivne = ?", odbcConnection);

            odbcCommand.Parameters.Add("@konto", OdbcType.NVarChar).Value = konto;

            odbcCommand.Parameters.Add("@konto_aktivne", OdbcType.Char).Value = aktivne;

            odbcConnection.Open();

            using (OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader())
            {
                if (!odbcDataReader.Read())
                {
                    odbcDataReader.Close();
                    odbcConnection.Close();

                    return null;
                }
                osoba = new Osoba();

                osoba.Id = odbcDataReader.GetInt32(0);

                odbcDataReader.Close();
            }

            odbcConnection.Close();
        }

        return osoba;
    }
}
