using System;
using System.Data;
using System.Data.Odbc;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Caching;

public partial class AdresaDAL
{
    public static void Delete( Adresa adresa )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "DELETE FROM alumni.adresa WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = adresa.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache.Remove("Adresa_" + adresa.Id.ToString());

             odbcConnection.Close();
        }
    }

    public static void Insert( Adresa adresa )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "INSERT INTO alumni.adresa( " +
                "osoba_id, zamestnanie_id, ulica, psc, mesto, stat_id ) " +
                "VALUES (?, ?, ?, ?, ?, ?)", odbcConnection
             );

             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = ( adresa.OsobaId == null ? null : adresa.OsobaId );
             odbcCommand.Parameters.Add("@zamestnanie_id", OdbcType.Int).Value = ( adresa.ZamestnanieId == null ? null : adresa.ZamestnanieId );
             odbcCommand.Parameters.Add("@ulica", OdbcType.NText).Value = adresa.Ulica;
             odbcCommand.Parameters.Add("@psc", OdbcType.NVarChar).Value = adresa.Psc;
             odbcCommand.Parameters.Add("@mesto", OdbcType.NVarChar).Value = adresa.Mesto;
             odbcCommand.Parameters.Add("@stat_id", OdbcType.Int).Value = adresa.StatId;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             odbcConnection.Close();
        }
    }

    public static List<Adresa> Select()
    {
        List<Adresa> adresaList = new List<Adresa>();
        Adresa adresa;
        int id;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.adresa", odbcConnection );

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 while ( odbcDataReader.Read() )
                 {
                     id = odbcDataReader.GetInt32(0);

                     adresa = (Adresa)HttpContext.Current.Cache["Adresa_" + id.ToString()];

                     if( adresa == null )
                     {
                         adresa = new Adresa();

                         adresa.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                         HttpContext.Current.Cache["Adresa_" + id.ToString()] = adresa;
                     }

                     adresaList.Add( adresa );
                 }

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return adresaList;
    }

    public static Adresa SelectById( int id )
    {
        Adresa adresa = (Adresa)HttpContext.Current.Cache["Adresa_" + id.ToString()];

        if( adresa != null ) return adresa;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.adresa WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = id;

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 if( !odbcDataReader.Read() )
                 {
                     odbcDataReader.Close();
                     odbcConnection.Close();

                     return null;
                 }

                 adresa = new Adresa();

                 adresa.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                 odbcDataReader.Close();

                 HttpContext.Current.Cache["Adresa_" + id.ToString()] = adresa;
             }

             odbcConnection.Close();
        }

        return adresa;
    }

    public static int SelectCount()
    {
        int rowCount;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT COUNT(*) FROM alumni.adresa", odbcConnection );

             odbcConnection.Open();

             rowCount = Convert.ToInt32( odbcCommand.ExecuteScalar() );

             odbcConnection.Close();
        }

        return rowCount;
    }

    public static void Update( Adresa adresa )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "UPDATE alumni.adresa SET " +
                "osoba_id = ?, zamestnanie_id = ?, ulica = ?, psc = ?, mesto = ?, " +
                "stat_id = ? " +
                "WHERE id = ?", odbcConnection
             );

             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = ( adresa.OsobaId == null ? null : adresa.OsobaId );
             odbcCommand.Parameters.Add("@zamestnanie_id", OdbcType.Int).Value = ( adresa.ZamestnanieId == null ? null : adresa.ZamestnanieId );
             odbcCommand.Parameters.Add("@ulica", OdbcType.NText).Value = adresa.Ulica;
             odbcCommand.Parameters.Add("@psc", OdbcType.NVarChar).Value = adresa.Psc;
             odbcCommand.Parameters.Add("@mesto", OdbcType.NVarChar).Value = adresa.Mesto;
             odbcCommand.Parameters.Add("@stat_id", OdbcType.Int).Value = adresa.StatId;
             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = adresa.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache["Adresa_" + adresa.Id.ToString()] = adresa;

             odbcConnection.Close();
        }
    }
}
