using System;
using System.Data;
using System.Data.Odbc;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Caching;

public partial class JazykDAL
{
    public static void Delete( Jazyk jazyk )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "DELETE FROM alumni.jazyk WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = jazyk.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache.Remove("Jazyk_" + jazyk.Id.ToString());

             odbcConnection.Close();
        }
    }

    public static void Insert( Jazyk jazyk )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "INSERT INTO alumni.jazyk( " +
                "osoba_id, porozumenie_pocuvanie, porozumenie_citanie, hovorenie_interakcia, " +
                "hovorenie_prejav, pisanie, nazov ) " +
                "VALUES (?, ?, ?, ?, ?, ?, ?)", odbcConnection
             );

             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = jazyk.OsobaId;
             odbcCommand.Parameters.Add("@porozumenie_pocuvanie", OdbcType.Int).Value = jazyk.PorozumeniePocuvanie;
             odbcCommand.Parameters.Add("@porozumenie_citanie", OdbcType.Int).Value = jazyk.PorozumenieCitanie;
             odbcCommand.Parameters.Add("@hovorenie_interakcia", OdbcType.Int).Value = jazyk.HovorenieInterakcia;
             odbcCommand.Parameters.Add("@hovorenie_prejav", OdbcType.Int).Value = jazyk.HovoreniePrejav;
             odbcCommand.Parameters.Add("@pisanie", OdbcType.Int).Value = jazyk.Pisanie;
             odbcCommand.Parameters.Add("@nazov", OdbcType.NVarChar).Value = jazyk.Nazov;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             odbcConnection.Close();
        }
    }

    public static List<Jazyk> Select()
    {
        List<Jazyk> jazykList = new List<Jazyk>();
        Jazyk jazyk;
        int id;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.jazyk", odbcConnection );

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 while ( odbcDataReader.Read() )
                 {
                     id = odbcDataReader.GetInt32(0);

                     jazyk = (Jazyk)HttpContext.Current.Cache["Jazyk_" + id.ToString()];

                     if( jazyk == null )
                     {
                         jazyk = new Jazyk();

                         jazyk.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                         HttpContext.Current.Cache["Jazyk_" + id.ToString()] = jazyk;
                     }

                     jazykList.Add( jazyk );
                 }

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return jazykList;
    }

    public static Jazyk SelectById( int id )
    {
        Jazyk jazyk = (Jazyk)HttpContext.Current.Cache["Jazyk_" + id.ToString()];

        if( jazyk != null ) return jazyk;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.jazyk WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = id;

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 if( !odbcDataReader.Read() )
                 {
                     odbcDataReader.Close();
                     odbcConnection.Close();

                     return null;
                 }

                 jazyk = new Jazyk();

                 jazyk.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                 odbcDataReader.Close();

                 HttpContext.Current.Cache["Jazyk_" + id.ToString()] = jazyk;
             }

             odbcConnection.Close();
        }

        return jazyk;
    }

    public static int SelectCount()
    {
        int rowCount;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT COUNT(*) FROM alumni.jazyk", odbcConnection );

             odbcConnection.Open();

             rowCount = Convert.ToInt32( odbcCommand.ExecuteScalar() );

             odbcConnection.Close();
        }

        return rowCount;
    }

    public static void Update( Jazyk jazyk )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "UPDATE alumni.jazyk SET " +
                "osoba_id = ?, porozumenie_pocuvanie = ?, porozumenie_citanie = ?, " +
                "hovorenie_interakcia = ?, hovorenie_prejav = ?, pisanie = ?, nazov = ? " +
                "WHERE id = ?", odbcConnection
             );

             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = jazyk.OsobaId;
             odbcCommand.Parameters.Add("@porozumenie_pocuvanie", OdbcType.Int).Value = jazyk.PorozumeniePocuvanie;
             odbcCommand.Parameters.Add("@porozumenie_citanie", OdbcType.Int).Value = jazyk.PorozumenieCitanie;
             odbcCommand.Parameters.Add("@hovorenie_interakcia", OdbcType.Int).Value = jazyk.HovorenieInterakcia;
             odbcCommand.Parameters.Add("@hovorenie_prejav", OdbcType.Int).Value = jazyk.HovoreniePrejav;
             odbcCommand.Parameters.Add("@pisanie", OdbcType.Int).Value = jazyk.Pisanie;
             odbcCommand.Parameters.Add("@nazov", OdbcType.NVarChar).Value = jazyk.Nazov;
             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = jazyk.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache["Jazyk_" + jazyk.Id.ToString()] = jazyk;

             odbcConnection.Close();
        }
    }
}
