using System;
using System.Data;
using System.Data.Odbc;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Caching;

public partial class KurzDAL
{
    public static void Delete( Kurz kurz )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "DELETE FROM alumni.kurz WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = kurz.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache.Remove("Kurz_" + kurz.Id.ToString());

             odbcConnection.Close();
        }
    }

    public static void Insert( Kurz kurz )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "INSERT INTO alumni.kurz( " +
                "nazov, datum_od, datum_do, poznamka, osoba_id ) " +
                "VALUES (?, ?, ?, ?, ?)", odbcConnection
             );

             odbcCommand.Parameters.Add("@nazov", OdbcType.NVarChar).Value = kurz.Nazov;
             odbcCommand.Parameters.Add("@datum_od", OdbcType.Date).Value = ( kurz.DatumOd == null ? null : kurz.DatumOd );
             odbcCommand.Parameters.Add("@datum_do", OdbcType.Date).Value = ( kurz.DatumDo == null ? null : kurz.DatumDo );
             odbcCommand.Parameters.Add("@poznamka", OdbcType.NText).Value = ( kurz.Poznamka == null ? null : kurz.Poznamka );
             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = kurz.OsobaId;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             odbcConnection.Close();
        }
    }

    public static List<Kurz> Select()
    {
        List<Kurz> kurzList = new List<Kurz>();
        Kurz kurz;
        int id;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.kurz", odbcConnection );

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 while ( odbcDataReader.Read() )
                 {
                     id = odbcDataReader.GetInt32(0);

                     kurz = (Kurz)HttpContext.Current.Cache["Kurz_" + id.ToString()];

                     if( kurz == null )
                     {
                         kurz = new Kurz();

                         kurz.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                         HttpContext.Current.Cache["Kurz_" + id.ToString()] = kurz;
                     }

                     kurzList.Add( kurz );
                 }

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return kurzList;
    }

    public static Kurz SelectById( int id )
    {
        Kurz kurz = (Kurz)HttpContext.Current.Cache["Kurz_" + id.ToString()];

        if( kurz != null ) return kurz;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.kurz WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = id;

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 if( !odbcDataReader.Read() )
                 {
                     odbcDataReader.Close();
                     odbcConnection.Close();

                     return null;
                 }

                 kurz = new Kurz();

                 kurz.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                 odbcDataReader.Close();

                 HttpContext.Current.Cache["Kurz_" + id.ToString()] = kurz;
             }

             odbcConnection.Close();
        }

        return kurz;
    }

    public static int SelectCount()
    {
        int rowCount;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT COUNT(*) FROM alumni.kurz", odbcConnection );

             odbcConnection.Open();

             rowCount = Convert.ToInt32( odbcCommand.ExecuteScalar() );

             odbcConnection.Close();
        }

        return rowCount;
    }

    public static void Update( Kurz kurz )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "UPDATE alumni.kurz SET " +
                "nazov = ?, datum_od = ?, datum_do = ?, poznamka = ?, osoba_id = ? " +
                "WHERE id = ?", odbcConnection
             );

             odbcCommand.Parameters.Add("@nazov", OdbcType.NVarChar).Value = kurz.Nazov;
             odbcCommand.Parameters.Add("@datum_od", OdbcType.Date).Value = ( kurz.DatumOd == null ? null : kurz.DatumOd );
             odbcCommand.Parameters.Add("@datum_do", OdbcType.Date).Value = ( kurz.DatumDo == null ? null : kurz.DatumDo );
             odbcCommand.Parameters.Add("@poznamka", OdbcType.NText).Value = ( kurz.Poznamka == null ? null : kurz.Poznamka );
             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = kurz.OsobaId;
             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = kurz.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache["Kurz_" + kurz.Id.ToString()] = kurz;

             odbcConnection.Close();
        }
    }
}
