using System;
using System.Data;
using System.Data.Odbc;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Caching;

public partial class OznamDAL
{
    public static void Delete( Oznam oznam )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "DELETE FROM alumni.oznam WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = oznam.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache.Remove("Oznam_" + oznam.Id.ToString());

             odbcConnection.Close();
        }
    }

    public static void Insert( Oznam oznam )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "INSERT INTO alumni.oznam( " +
                "osoba_id, nazov, datum_platnosti, typ_oznamu_id, popis ) " +
                "VALUES (?, ?, ?, ?, ?)", odbcConnection
             );

             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = oznam.OsobaId;
             odbcCommand.Parameters.Add("@nazov", OdbcType.NVarChar).Value = oznam.Nazov;
             odbcCommand.Parameters.Add("@datum_platnosti", OdbcType.Date).Value = oznam.DatumPlatnosti;
             odbcCommand.Parameters.Add("@typ_oznamu_id", OdbcType.Int).Value = oznam.TypOznamuId;
             odbcCommand.Parameters.Add("@popis", OdbcType.NText).Value = oznam.Popis;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             odbcConnection.Close();
        }
    }

    public static List<Oznam> Select()
    {
        List<Oznam> oznamList = new List<Oznam>();
        Oznam oznam;
        int id;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.oznam", odbcConnection );

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 while ( odbcDataReader.Read() )
                 {
                     id = odbcDataReader.GetInt32(0);

                     oznam = (Oznam)HttpContext.Current.Cache["Oznam_" + id.ToString()];

                     if( oznam == null )
                     {
                         oznam = new Oznam();

                         oznam.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                         HttpContext.Current.Cache["Oznam_" + id.ToString()] = oznam;
                     }

                     oznamList.Add( oznam );
                 }

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return oznamList;
    }

    public static Oznam SelectById( int id )
    {
        Oznam oznam = (Oznam)HttpContext.Current.Cache["Oznam_" + id.ToString()];

        if( oznam != null ) return oznam;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.oznam WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = id;

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 if( !odbcDataReader.Read() )
                 {
                     odbcDataReader.Close();
                     odbcConnection.Close();

                     return null;
                 }

                 oznam = new Oznam();

                 oznam.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                 odbcDataReader.Close();

                 HttpContext.Current.Cache["Oznam_" + id.ToString()] = oznam;
             }

             odbcConnection.Close();
        }

        return oznam;
    }

    public static int SelectCount()
    {
        int rowCount;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT COUNT(*) FROM alumni.oznam", odbcConnection );

             odbcConnection.Open();

             rowCount = Convert.ToInt32( odbcCommand.ExecuteScalar() );

             odbcConnection.Close();
        }

        return rowCount;
    }

    public static void Update( Oznam oznam )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "UPDATE alumni.oznam SET " +
                "osoba_id = ?, nazov = ?, datum_platnosti = ?, typ_oznamu_id = ?, " +
                "popis = ? " +
                "WHERE id = ?", odbcConnection
             );

             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = oznam.OsobaId;
             odbcCommand.Parameters.Add("@nazov", OdbcType.NVarChar).Value = oznam.Nazov;
             odbcCommand.Parameters.Add("@datum_platnosti", OdbcType.Date).Value = oznam.DatumPlatnosti;
             odbcCommand.Parameters.Add("@typ_oznamu_id", OdbcType.Int).Value = oznam.TypOznamuId;
             odbcCommand.Parameters.Add("@popis", OdbcType.NText).Value = oznam.Popis;
             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = oznam.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache["Oznam_" + oznam.Id.ToString()] = oznam;

             odbcConnection.Close();
        }
    }
}
