using System;
using System.Data;
using System.Data.Odbc;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Caching;

public partial class PrispevokDAL
{
    public static void Delete( Prispevok prispevok )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "DELETE FROM alumni.prispevok WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = prispevok.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache.Remove("Prispevok_" + prispevok.Id.ToString());

             odbcConnection.Close();
        }
    }

    public static void Insert( Prispevok prispevok )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "INSERT INTO alumni.prispevok( " +
                "text, cas, tema_id, osoba_id, predmet ) " +
                "VALUES (?, ?, ?, ?, ?)", odbcConnection
             );

             odbcCommand.Parameters.Add("@text", OdbcType.NText).Value = prispevok.Text;
             odbcCommand.Parameters.Add("@cas", OdbcType.DateTime).Value = prispevok.Cas;
             odbcCommand.Parameters.Add("@tema_id", OdbcType.Int).Value = prispevok.TemaId;
             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = prispevok.OsobaId;
             odbcCommand.Parameters.Add("@predmet", OdbcType.NVarChar).Value = ( prispevok.Predmet == null ? null : prispevok.Predmet );

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             odbcConnection.Close();
        }
    }

    public static List<Prispevok> Select()
    {
        List<Prispevok> prispevokList = new List<Prispevok>();
        Prispevok prispevok;
        int id;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.prispevok", odbcConnection );

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 while ( odbcDataReader.Read() )
                 {
                     id = odbcDataReader.GetInt32(0);

                     prispevok = (Prispevok)HttpContext.Current.Cache["Prispevok_" + id.ToString()];

                     if( prispevok == null )
                     {
                         prispevok = new Prispevok();

                         prispevok.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                         HttpContext.Current.Cache["Prispevok_" + id.ToString()] = prispevok;
                     }

                     prispevokList.Add( prispevok );
                 }

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return prispevokList;
    }

    public static Prispevok SelectById( int id )
    {
        Prispevok prispevok = (Prispevok)HttpContext.Current.Cache["Prispevok_" + id.ToString()];

        if( prispevok != null ) return prispevok;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.prispevok WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = id;

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 if( !odbcDataReader.Read() )
                 {
                     odbcDataReader.Close();
                     odbcConnection.Close();

                     return null;
                 }

                 prispevok = new Prispevok();

                 prispevok.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                 odbcDataReader.Close();

                 HttpContext.Current.Cache["Prispevok_" + id.ToString()] = prispevok;
             }

             odbcConnection.Close();
        }

        return prispevok;
    }

    public static int SelectCount()
    {
        int rowCount;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT COUNT(*) FROM alumni.prispevok", odbcConnection );

             odbcConnection.Open();

             rowCount = Convert.ToInt32( odbcCommand.ExecuteScalar() );

             odbcConnection.Close();
        }

        return rowCount;
    }

    public static void Update( Prispevok prispevok )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "UPDATE alumni.prispevok SET " +
                "text = ?, cas = ?, tema_id = ?, osoba_id = ?, predmet = ? " +
                "WHERE id = ?", odbcConnection
             );

             odbcCommand.Parameters.Add("@text", OdbcType.NText).Value = prispevok.Text;
             odbcCommand.Parameters.Add("@cas", OdbcType.DateTime).Value = prispevok.Cas;
             odbcCommand.Parameters.Add("@tema_id", OdbcType.Int).Value = prispevok.TemaId;
             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = prispevok.OsobaId;
             odbcCommand.Parameters.Add("@predmet", OdbcType.NVarChar).Value = ( prispevok.Predmet == null ? null : prispevok.Predmet );
             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = prispevok.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache["Prispevok_" + prispevok.Id.ToString()] = prispevok;

             odbcConnection.Close();
        }
    }
}
