using System;
using System.Data;
using System.Data.Odbc;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Caching;

public partial class ProjektDAL
{
    public static void Delete( Projekt projekt )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "DELETE FROM alumni.projekt WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = projekt.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache.Remove("Projekt_" + projekt.Id.ToString());

             odbcConnection.Close();
        }
    }

    public static void Insert( Projekt projekt )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "INSERT INTO alumni.projekt( " +
                "osoba_id, job_id, studium_id, nazov, abstrakt, veduci, klucove_slova, " +
                "datum_vypracovania, www_odkaz, poznamka ) " +
                "VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)", odbcConnection
             );

             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = projekt.OsobaId;
             odbcCommand.Parameters.Add("@job_id", OdbcType.Int).Value = ( projekt.JobId == null ? null : projekt.JobId );
             odbcCommand.Parameters.Add("@studium_id", OdbcType.Int).Value = ( projekt.StudiumId == null ? null : projekt.StudiumId );
             odbcCommand.Parameters.Add("@nazov", OdbcType.NVarChar).Value = projekt.Nazov;
             odbcCommand.Parameters.Add("@abstrakt", OdbcType.NText).Value = ( projekt.Abstrakt == null ? null : projekt.Abstrakt );
             odbcCommand.Parameters.Add("@veduci", OdbcType.NVarChar).Value = ( projekt.Veduci == null ? null : projekt.Veduci );
             odbcCommand.Parameters.Add("@klucove_slova", OdbcType.NText).Value = projekt.KlucoveSlova;
             odbcCommand.Parameters.Add("@datum_vypracovania", OdbcType.Date).Value = projekt.DatumVypracovania;
             odbcCommand.Parameters.Add("@www_odkaz", OdbcType.NText).Value = ( projekt.WwwOdkaz == null ? null : projekt.WwwOdkaz );
             odbcCommand.Parameters.Add("@poznamka", OdbcType.NText).Value = ( projekt.Poznamka == null ? null : projekt.Poznamka );

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             odbcConnection.Close();
        }
    }

    public static List<Projekt> Select()
    {
        List<Projekt> projektList = new List<Projekt>();
        Projekt projekt;
        int id;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.projekt", odbcConnection );

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 while ( odbcDataReader.Read() )
                 {
                     id = odbcDataReader.GetInt32(0);

                     projekt = (Projekt)HttpContext.Current.Cache["Projekt_" + id.ToString()];

                     if( projekt == null )
                     {
                         projekt = new Projekt();

                         projekt.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                         HttpContext.Current.Cache["Projekt_" + id.ToString()] = projekt;
                     }

                     projektList.Add( projekt );
                 }

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return projektList;
    }

    public static Projekt SelectById( int id )
    {
        Projekt projekt = (Projekt)HttpContext.Current.Cache["Projekt_" + id.ToString()];

        if( projekt != null ) return projekt;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.projekt WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = id;

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 if( !odbcDataReader.Read() )
                 {
                     odbcDataReader.Close();
                     odbcConnection.Close();

                     return null;
                 }

                 projekt = new Projekt();

                 projekt.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                 odbcDataReader.Close();

                 HttpContext.Current.Cache["Projekt_" + id.ToString()] = projekt;
             }

             odbcConnection.Close();
        }

        return projekt;
    }

    public static int SelectCount()
    {
        int rowCount;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT COUNT(*) FROM alumni.projekt", odbcConnection );

             odbcConnection.Open();

             rowCount = Convert.ToInt32( odbcCommand.ExecuteScalar() );

             odbcConnection.Close();
        }

        return rowCount;
    }

    public static void Update( Projekt projekt )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "UPDATE alumni.projekt SET " +
                "osoba_id = ?, job_id = ?, studium_id = ?, nazov = ?, abstrakt = ?, " +
                "veduci = ?, klucove_slova = ?, datum_vypracovania = ?, www_odkaz = ?, " +
                "poznamka = ? " +
                "WHERE id = ?", odbcConnection
             );

             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = projekt.OsobaId;
             odbcCommand.Parameters.Add("@job_id", OdbcType.Int).Value = ( projekt.JobId == null ? null : projekt.JobId );
             odbcCommand.Parameters.Add("@studium_id", OdbcType.Int).Value = ( projekt.StudiumId == null ? null : projekt.StudiumId );
             odbcCommand.Parameters.Add("@nazov", OdbcType.NVarChar).Value = projekt.Nazov;
             odbcCommand.Parameters.Add("@abstrakt", OdbcType.NText).Value = ( projekt.Abstrakt == null ? null : projekt.Abstrakt );
             odbcCommand.Parameters.Add("@veduci", OdbcType.NVarChar).Value = ( projekt.Veduci == null ? null : projekt.Veduci );
             odbcCommand.Parameters.Add("@klucove_slova", OdbcType.NText).Value = projekt.KlucoveSlova;
             odbcCommand.Parameters.Add("@datum_vypracovania", OdbcType.Date).Value = projekt.DatumVypracovania;
             odbcCommand.Parameters.Add("@www_odkaz", OdbcType.NText).Value = ( projekt.WwwOdkaz == null ? null : projekt.WwwOdkaz );
             odbcCommand.Parameters.Add("@poznamka", OdbcType.NText).Value = ( projekt.Poznamka == null ? null : projekt.Poznamka );
             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = projekt.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache["Projekt_" + projekt.Id.ToString()] = projekt;

             odbcConnection.Close();
        }
    }
}
