using System;
using System.Data;
using System.Data.Odbc;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Caching;

public partial class RegistraciaDAL
{
    public static void Delete( Registracia registracia )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "DELETE FROM alumni.registracia WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = registracia.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache.Remove("Registracia_" + registracia.Id.ToString());

             odbcConnection.Close();
        }
    }

    public static void Insert( Registracia registracia )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "INSERT INTO alumni.registracia( " +
                "email, heslo, meno, priezvisko, datum_narodenia, rok_absolvovania, " +
                "typ_registracie_id ) " +
                "VALUES (?, ?, ?, ?, ?, ?, ?)", odbcConnection
             );

             odbcCommand.Parameters.Add("@email", OdbcType.NVarChar).Value = registracia.Email;
             odbcCommand.Parameters.Add("@heslo", OdbcType.NText).Value = registracia.Heslo;
             odbcCommand.Parameters.Add("@meno", OdbcType.NVarChar).Value = registracia.Meno;
             odbcCommand.Parameters.Add("@priezvisko", OdbcType.NVarChar).Value = registracia.Priezvisko;
             odbcCommand.Parameters.Add("@datum_narodenia", OdbcType.Date).Value = registracia.DatumNarodenia;
             odbcCommand.Parameters.Add("@rok_absolvovania", OdbcType.Int).Value = ( registracia.RokAbsolvovania == null ? null : registracia.RokAbsolvovania );
             odbcCommand.Parameters.Add("@typ_registracie_id", OdbcType.Int).Value = registracia.TypRegistracieId;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             odbcConnection.Close();
        }
    }

    public static List<Registracia> Select()
    {
        List<Registracia> registraciaList = new List<Registracia>();
        Registracia registracia;
        int id;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.registracia", odbcConnection );

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 while ( odbcDataReader.Read() )
                 {
                     id = odbcDataReader.GetInt32(0);

                     registracia = (Registracia)HttpContext.Current.Cache["Registracia_" + id.ToString()];

                     if( registracia == null )
                     {
                         registracia = new Registracia();

                         registracia.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                         HttpContext.Current.Cache["Registracia_" + id.ToString()] = registracia;
                     }

                     registraciaList.Add( registracia );
                 }

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return registraciaList;
    }

    public static Registracia SelectById( int id )
    {
        Registracia registracia = (Registracia)HttpContext.Current.Cache["Registracia_" + id.ToString()];

        if( registracia != null ) return registracia;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.registracia WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = id;

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 if( !odbcDataReader.Read() )
                 {
                     odbcDataReader.Close();
                     odbcConnection.Close();

                     return null;
                 }

                 registracia = new Registracia();

                 registracia.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                 odbcDataReader.Close();

                 HttpContext.Current.Cache["Registracia_" + id.ToString()] = registracia;
             }

             odbcConnection.Close();
        }

        return registracia;
    }

    public static int SelectCount()
    {
        int rowCount;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT COUNT(*) FROM alumni.registracia", odbcConnection );

             odbcConnection.Open();

             rowCount = Convert.ToInt32( odbcCommand.ExecuteScalar() );

             odbcConnection.Close();
        }

        return rowCount;
    }

    public static void Update( Registracia registracia )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "UPDATE alumni.registracia SET " +
                "email = ?, heslo = ?, meno = ?, priezvisko = ?, datum_narodenia = ?, " +
                "rok_absolvovania = ?, typ_registracie_id = ? " +
                "WHERE id = ?", odbcConnection
             );

             odbcCommand.Parameters.Add("@email", OdbcType.NVarChar).Value = registracia.Email;
             odbcCommand.Parameters.Add("@heslo", OdbcType.NText).Value = registracia.Heslo;
             odbcCommand.Parameters.Add("@meno", OdbcType.NVarChar).Value = registracia.Meno;
             odbcCommand.Parameters.Add("@priezvisko", OdbcType.NVarChar).Value = registracia.Priezvisko;
             odbcCommand.Parameters.Add("@datum_narodenia", OdbcType.Date).Value = registracia.DatumNarodenia;
             odbcCommand.Parameters.Add("@rok_absolvovania", OdbcType.Int).Value = ( registracia.RokAbsolvovania == null ? null : registracia.RokAbsolvovania );
             odbcCommand.Parameters.Add("@typ_registracie_id", OdbcType.Int).Value = registracia.TypRegistracieId;
             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = registracia.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache["Registracia_" + registracia.Id.ToString()] = registracia;

             odbcConnection.Close();
        }
    }
}
