using System;
using System.Data;
using System.Data.Odbc;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Caching;

public partial class StudiumDAL
{
    public static void Delete( Studium studium )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "DELETE FROM alumni.studium WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = studium.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache.Remove("Studium_" + studium.Id.ToString());

             odbcConnection.Close();
        }
    }

    public static void Insert( Studium studium )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "INSERT INTO alumni.studium( " +
                "osoba_id, skola_id, smer_id, stupen, osobne_cislo, datum_od, datum_do, " +
                "prospech, fakulta, odbor, typ_skoly, ziskany_titul ) " +
                "VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)", odbcConnection
             );

             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = studium.OsobaId;
             odbcCommand.Parameters.Add("@skola_id", OdbcType.Int).Value = studium.SkolaId;
             odbcCommand.Parameters.Add("@smer_id", OdbcType.Int).Value = ( studium.SmerId == null ? null : studium.SmerId );
             odbcCommand.Parameters.Add("@stupen", OdbcType.Numeric).Value = studium.Stupen;
             odbcCommand.Parameters.Add("@osobne_cislo", OdbcType.Numeric).Value = ( studium.OsobneCislo == null ? null : studium.OsobneCislo );
             odbcCommand.Parameters.Add("@datum_od", OdbcType.Date).Value = studium.DatumOd;
             odbcCommand.Parameters.Add("@datum_do", OdbcType.Date).Value = ( studium.DatumDo == null ? null : studium.DatumDo );
             odbcCommand.Parameters.Add("@prospech", OdbcType.Numeric).Value = ( studium.Prospech == null ? null : studium.Prospech );
             odbcCommand.Parameters.Add("@fakulta", OdbcType.NVarChar).Value = ( studium.Fakulta == null ? null : studium.Fakulta );
             odbcCommand.Parameters.Add("@odbor", OdbcType.NVarChar).Value = ( studium.Odbor == null ? null : studium.Odbor );
             odbcCommand.Parameters.Add("@typ_skoly", OdbcType.Numeric).Value = ( studium.TypSkoly == null ? null : studium.TypSkoly );
             odbcCommand.Parameters.Add("@ziskany_titul", OdbcType.NVarChar).Value = ( studium.ZiskanyTitul == null ? null : studium.ZiskanyTitul );

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             odbcConnection.Close();
        }
    }

    public static List<Studium> Select()
    {
        List<Studium> studiumList = new List<Studium>();
        Studium studium;
        int id;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.studium", odbcConnection );

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 while ( odbcDataReader.Read() )
                 {
                     id = odbcDataReader.GetInt32(0);

                     studium = (Studium)HttpContext.Current.Cache["Studium_" + id.ToString()];

                     if( studium == null )
                     {
                         studium = new Studium();

                         studium.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                         HttpContext.Current.Cache["Studium_" + id.ToString()] = studium;
                     }

                     studiumList.Add( studium );
                 }

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return studiumList;
    }

    public static Studium SelectById( int id )
    {
        Studium studium = (Studium)HttpContext.Current.Cache["Studium_" + id.ToString()];

        if( studium != null ) return studium;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.studium WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = id;

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 if( !odbcDataReader.Read() )
                 {
                     odbcDataReader.Close();
                     odbcConnection.Close();

                     return null;
                 }

                 studium = new Studium();

                 studium.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                 odbcDataReader.Close();

                 HttpContext.Current.Cache["Studium_" + id.ToString()] = studium;
             }

             odbcConnection.Close();
        }

        return studium;
    }

    public static int SelectCount()
    {
        int rowCount;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT COUNT(*) FROM alumni.studium", odbcConnection );

             odbcConnection.Open();

             rowCount = Convert.ToInt32( odbcCommand.ExecuteScalar() );

             odbcConnection.Close();
        }

        return rowCount;
    }

    public static void Update( Studium studium )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "UPDATE alumni.studium SET " +
                "osoba_id = ?, skola_id = ?, smer_id = ?, stupen = ?, osobne_cislo = ?, " +
                "datum_od = ?, datum_do = ?, prospech = ?, fakulta = ?, odbor = ?, " +
                "typ_skoly = ?, ziskany_titul = ? " +
                "WHERE id = ?", odbcConnection
             );

             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = studium.OsobaId;
             odbcCommand.Parameters.Add("@skola_id", OdbcType.Int).Value = studium.SkolaId;
             odbcCommand.Parameters.Add("@smer_id", OdbcType.Int).Value = ( studium.SmerId == null ? null : studium.SmerId );
             odbcCommand.Parameters.Add("@stupen", OdbcType.Numeric).Value = studium.Stupen;
             odbcCommand.Parameters.Add("@osobne_cislo", OdbcType.Numeric).Value = ( studium.OsobneCislo == null ? null : studium.OsobneCislo );
             odbcCommand.Parameters.Add("@datum_od", OdbcType.Date).Value = studium.DatumOd;
             odbcCommand.Parameters.Add("@datum_do", OdbcType.Date).Value = ( studium.DatumDo == null ? null : studium.DatumDo );
             odbcCommand.Parameters.Add("@prospech", OdbcType.Numeric).Value = ( studium.Prospech == null ? null : studium.Prospech );
             odbcCommand.Parameters.Add("@fakulta", OdbcType.NVarChar).Value = ( studium.Fakulta == null ? null : studium.Fakulta );
             odbcCommand.Parameters.Add("@odbor", OdbcType.NVarChar).Value = ( studium.Odbor == null ? null : studium.Odbor );
             odbcCommand.Parameters.Add("@typ_skoly", OdbcType.Numeric).Value = ( studium.TypSkoly == null ? null : studium.TypSkoly );
             odbcCommand.Parameters.Add("@ziskany_titul", OdbcType.NVarChar).Value = ( studium.ZiskanyTitul == null ? null : studium.ZiskanyTitul );
             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = studium.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache["Studium_" + studium.Id.ToString()] = studium;

             odbcConnection.Close();
        }
    }
}
