using System;
using System.Data;
using System.Data.Odbc;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Caching;

public partial class TemaDAL
{
    public static void Delete( Tema tema )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "DELETE FROM alumni.tema WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = tema.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache.Remove("Tema_" + tema.Id.ToString());

             odbcConnection.Close();
        }
    }

    public static void Insert( Tema tema )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "INSERT INTO alumni.tema( " +
                "nazov, popis, cas, je_verejna, osoba_id, nadtema ) " +
                "VALUES (?, ?, ?, ?, ?, ?)", odbcConnection
             );

             odbcCommand.Parameters.Add("@nazov", OdbcType.NVarChar).Value = tema.Nazov;
             odbcCommand.Parameters.Add("@popis", OdbcType.NText).Value = ( tema.Popis == null ? null : tema.Popis );
             odbcCommand.Parameters.Add("@cas", OdbcType.DateTime).Value = tema.Cas;
             odbcCommand.Parameters.Add("@je_verejna", OdbcType.Char).Value = tema.JeVerejna;
             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = tema.OsobaId;
             odbcCommand.Parameters.Add("@nadtema", OdbcType.Int).Value = ( tema.Nadtema == null ? null : tema.Nadtema );

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             odbcConnection.Close();
        }
    }

    public static List<Tema> Select()
    {
        List<Tema> temaList = new List<Tema>();
        Tema tema;
        int id;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.tema", odbcConnection );

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 while ( odbcDataReader.Read() )
                 {
                     id = odbcDataReader.GetInt32(0);

                     tema = (Tema)HttpContext.Current.Cache["Tema_" + id.ToString()];

                     if( tema == null )
                     {
                         tema = new Tema();

                         tema.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                         HttpContext.Current.Cache["Tema_" + id.ToString()] = tema;
                     }

                     temaList.Add( tema );
                 }

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return temaList;
    }

    public static Tema SelectById( int id )
    {
        Tema tema = (Tema)HttpContext.Current.Cache["Tema_" + id.ToString()];

        if( tema != null ) return tema;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.tema WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = id;

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 if( !odbcDataReader.Read() )
                 {
                     odbcDataReader.Close();
                     odbcConnection.Close();

                     return null;
                 }

                 tema = new Tema();

                 tema.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                 odbcDataReader.Close();

                 HttpContext.Current.Cache["Tema_" + id.ToString()] = tema;
             }

             odbcConnection.Close();
        }

        return tema;
    }

    public static int SelectCount()
    {
        int rowCount;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT COUNT(*) FROM alumni.tema", odbcConnection );

             odbcConnection.Open();

             rowCount = Convert.ToInt32( odbcCommand.ExecuteScalar() );

             odbcConnection.Close();
        }

        return rowCount;
    }

    public static void Update( Tema tema )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "UPDATE alumni.tema SET " +
                "nazov = ?, popis = ?, cas = ?, je_verejna = ?, osoba_id = ?, nadtema = ? " +
                "WHERE id = ?", odbcConnection
             );

             odbcCommand.Parameters.Add("@nazov", OdbcType.NVarChar).Value = tema.Nazov;
             odbcCommand.Parameters.Add("@popis", OdbcType.NText).Value = ( tema.Popis == null ? null : tema.Popis );
             odbcCommand.Parameters.Add("@cas", OdbcType.DateTime).Value = tema.Cas;
             odbcCommand.Parameters.Add("@je_verejna", OdbcType.Char).Value = tema.JeVerejna;
             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = tema.OsobaId;
             odbcCommand.Parameters.Add("@nadtema", OdbcType.Int).Value = ( tema.Nadtema == null ? null : tema.Nadtema );
             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = tema.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache["Tema_" + tema.Id.ToString()] = tema;

             odbcConnection.Close();
        }
    }
}
