using System;
using System.Data;
using System.Data.Odbc;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Caching;

public partial class ZamestnanieDAL
{
    public static void Delete( Zamestnanie zamestnanie )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "DELETE FROM alumni.zamestnanie WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = zamestnanie.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache.Remove("Zamestnanie_" + zamestnanie.Id.ToString());

             odbcConnection.Close();
        }
    }

    public static void Insert( Zamestnanie zamestnanie )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "INSERT INTO alumni.zamestnanie( " +
                "osoba_id, pozicia_odvetvie_id, datum_od, datum_do, nazov_firmy, " +
                "poznamka ) " +
                "VALUES (?, ?, ?, ?, ?, ?)", odbcConnection
             );

             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = zamestnanie.OsobaId;
             odbcCommand.Parameters.Add("@pozicia_odvetvie_id", OdbcType.Int).Value = ( zamestnanie.PoziciaOdvetvieId == null ? null : zamestnanie.PoziciaOdvetvieId );
             odbcCommand.Parameters.Add("@datum_od", OdbcType.Date).Value = zamestnanie.DatumOd;
             odbcCommand.Parameters.Add("@datum_do", OdbcType.Date).Value = ( zamestnanie.DatumDo == null ? null : zamestnanie.DatumDo );
             odbcCommand.Parameters.Add("@nazov_firmy", OdbcType.NVarChar).Value = zamestnanie.NazovFirmy;
             odbcCommand.Parameters.Add("@poznamka", OdbcType.NText).Value = ( zamestnanie.Poznamka == null ? null : zamestnanie.Poznamka );

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             odbcConnection.Close();
        }
    }

    public static List<Zamestnanie> Select()
    {
        List<Zamestnanie> zamestnanieList = new List<Zamestnanie>();
        Zamestnanie zamestnanie;
        int id;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.zamestnanie", odbcConnection );

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 while ( odbcDataReader.Read() )
                 {
                     id = odbcDataReader.GetInt32(0);

                     zamestnanie = (Zamestnanie)HttpContext.Current.Cache["Zamestnanie_" + id.ToString()];

                     if( zamestnanie == null )
                     {
                         zamestnanie = new Zamestnanie();

                         zamestnanie.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                         HttpContext.Current.Cache["Zamestnanie_" + id.ToString()] = zamestnanie;
                     }

                     zamestnanieList.Add( zamestnanie );
                 }

                 odbcDataReader.Close();
             }

             odbcConnection.Close();
        }

        return zamestnanieList;
    }

    public static Zamestnanie SelectById( int id )
    {
        Zamestnanie zamestnanie = (Zamestnanie)HttpContext.Current.Cache["Zamestnanie_" + id.ToString()];

        if( zamestnanie != null ) return zamestnanie;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT * FROM alumni.zamestnanie WHERE id = ?", odbcConnection );

             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = id;

             odbcConnection.Open();

             using ( OdbcDataReader odbcDataReader = odbcCommand.ExecuteReader() )
             {
                 if( !odbcDataReader.Read() )
                 {
                     odbcDataReader.Close();
                     odbcConnection.Close();

                     return null;
                 }

                 zamestnanie = new Zamestnanie();

                 zamestnanie.ValuesFromReader( odbcDataReader.GetInt32(0), odbcDataReader );

                 odbcDataReader.Close();

                 HttpContext.Current.Cache["Zamestnanie_" + id.ToString()] = zamestnanie;
             }

             odbcConnection.Close();
        }

        return zamestnanie;
    }

    public static int SelectCount()
    {
        int rowCount;

        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "SELECT COUNT(*) FROM alumni.zamestnanie", odbcConnection );

             odbcConnection.Open();

             rowCount = Convert.ToInt32( odbcCommand.ExecuteScalar() );

             odbcConnection.Close();
        }

        return rowCount;
    }

    public static void Update( Zamestnanie zamestnanie )
    {
        using ( OdbcConnection odbcConnection = new OdbcConnection( ConfigurationManager.ConnectionStrings["alumni"].ConnectionString ) )
        {
             OdbcCommand odbcCommand = new OdbcCommand( "UPDATE alumni.zamestnanie SET " +
                "osoba_id = ?, pozicia_odvetvie_id = ?, datum_od = ?, datum_do = ?, " +
                "nazov_firmy = ?, poznamka = ? " +
                "WHERE id = ?", odbcConnection
             );

             odbcCommand.Parameters.Add("@osoba_id", OdbcType.Int).Value = zamestnanie.OsobaId;
             odbcCommand.Parameters.Add("@pozicia_odvetvie_id", OdbcType.Int).Value = ( zamestnanie.PoziciaOdvetvieId == null ? null : zamestnanie.PoziciaOdvetvieId );
             odbcCommand.Parameters.Add("@datum_od", OdbcType.Date).Value = zamestnanie.DatumOd;
             odbcCommand.Parameters.Add("@datum_do", OdbcType.Date).Value = ( zamestnanie.DatumDo == null ? null : zamestnanie.DatumDo );
             odbcCommand.Parameters.Add("@nazov_firmy", OdbcType.NVarChar).Value = zamestnanie.NazovFirmy;
             odbcCommand.Parameters.Add("@poznamka", OdbcType.NText).Value = ( zamestnanie.Poznamka == null ? null : zamestnanie.Poznamka );
             odbcCommand.Parameters.Add("@id", OdbcType.Int).Value = zamestnanie.Id;

             odbcConnection.Open();

             odbcCommand.ExecuteNonQuery();

             HttpContext.Current.Cache["Zamestnanie_" + zamestnanie.Id.ToString()] = zamestnanie;

             odbcConnection.Close();
        }
    }
}
