using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Reflection;

public class ObjectComparer<T> : IComparer<T>
{
    private string direction;
    private string compareField;

    public ObjectComparer( string compareField, string direction )
    {
        this.compareField = compareField;
        this.direction = direction.ToUpper();
    }

    public string Direction
    {
        get { return direction; }
        set { direction = value; }
    }

    public string CompareField
    {
        get { return compareField; }
        set { compareField = value; }
    }

    public int Compare( T x, T y )
    {
        object compareValX = GetPropertyValue( x, compareField );
        object compareValY = GetPropertyValue( y, compareField );

        int compareValue = 0;

        if( compareValX == null && compareValY == null ) compareValue = 0;
        else if( compareValX == null ) compareValue = -1;
        else if( compareValY == null ) compareValue = 1;
        else compareValue = ( (IComparable)compareValX ).CompareTo( compareValY );

        if ( direction == "DESC" ) compareValue = -1 * compareValue;

        return compareValue;
    }

    private object GetPropertyValue( object o, string compareField )
    {
        PropertyInfo propertyInfo;
        object objectInstance = o;
        string[] propertyParts = compareField.Split( new char[]{'.'} );

        if( propertyParts.Length == 0 ) return null;

        for( int i = 0; i < propertyParts.Length; i++ )
        {
            if( objectInstance == null ) return null;
            propertyInfo = objectInstance.GetType().GetProperty( propertyParts[i] );
            objectInstance = propertyInfo.GetValue( objectInstance, null );
        }
        
        return objectInstance;
    }
}
