using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

public partial class EditCoursesUC : System.Web.UI.UserControl
{
    private Osoba osoba = null;
    private Kurz kurz = null;

    public Osoba Data
    {
        get { return osoba; }
        set { osoba = value; }
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        HideStatus();

        ODS_Courses.SelectParameters["osobaId"].DefaultValue = osoba.Id.ToString();
    }

    protected override void OnPreRender(EventArgs e)
    {
        base.OnPreRender(e);

        if ( GV_Courses.SelectedValue == null ) BN_Edit.Visible = false;
        else BN_Edit.Visible = true;
    }
  
    private void ShowError( string text )
    {
        LA_Status.ForeColor = System.Drawing.Color.Red;
        LA_Status.Text = text;
        LA_Status.Visible = true;
    }

    private void HideStatus()
    {
        LA_Status.Visible = false;
    }

    private void ShowSuccess( string text )
    {
        LA_Status.ForeColor = System.Drawing.Color.Green;
        LA_Status.Text = text;
        LA_Status.Visible = true;
    }

    private void SetFields( Kurz kurz )
    {
        TB_Finished.Text = kurz.DatumDo.HasValue ? kurz.DatumDo.Value.ToShortDateString().Replace(" ","") : null;
        TB_Name.Text = kurz.Nazov;
        TB_Note.Text = kurz.Poznamka;
        TB_Started.Text = kurz.DatumOd.HasValue ? kurz.DatumOd.Value.ToShortDateString().Replace(" ", "") : null;
    }
   
    private void ClearFields()
    {
        TB_Finished.Text = null;
        TB_Name.Text = null;
        TB_Note.Text = null;
        TB_Started.Text = null;
    }

    protected void BN_Insert_Click(object sender, EventArgs e)
    {
        HideStatus();

        kurz = new Kurz();

        kurz.OsobaId = osoba.Id;
        kurz.DatumDo = DateTime.Parse( TB_Finished.Text );
        kurz.Nazov = TB_Name.Text;
        kurz.Poznamka = TB_Note.Text;
        kurz.DatumOd = DateTime.Parse( TB_Started.Text );

        if( kurz.DatumOd > kurz.DatumDo ) 
        {
            ShowError("Nesprvne zadan dtumy!");
            return;
        }
        else KurzDAL.Insert( kurz );

        KurzDAL.Insert( kurz );

        ClearFields();

        GV_Courses.SelectedIndex = -1;

        ShowSuccess("Kurz bol pridan");
    }

    protected void BN_Edit_Click(object sender, EventArgs e)
    {
        HideStatus();

        kurz = KurzDAL.SelectById( (int)GV_Courses.SelectedValue );

        kurz.OsobaId = osoba.Id;
        kurz.DatumDo = DateTime.Parse( TB_Finished.Text );
        kurz.Nazov = TB_Name.Text;
        kurz.Poznamka = TB_Note.Text;
        kurz.DatumOd = DateTime.Parse( TB_Started.Text );

        if( kurz.DatumOd > kurz.DatumDo ) 
        {
            ShowError("Nesprvne zadan dtumy!");
            return;
        }
        else KurzDAL.Insert( kurz );

        KurzDAL.Update( kurz );

        ClearFields();

        GV_Courses.SelectedIndex = -1;

        ShowSuccess("Kurz bol upraven");
    }

    protected void GV_Courses_RowSelecting(object sender, GridViewSelectEventArgs e)
    {
        int id = Convert.ToInt32( GV_Courses.DataKeys[e.NewSelectedIndex].Value );

        kurz = KurzDAL.SelectById( id );
        
        SetFields( kurz );
    }

    protected void GV_Courses_RowDeleted(object sender, EventArgs e)
    {
        ShowSuccess("Kurz bol zmazan");
    }

    protected void BN_New_Click(object sender, EventArgs e)
    {
        ClearFields();

        GV_Courses.SelectedIndex = -1;
    }
}
