using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Collections.Generic;

public partial class EditJobsUC : System.Web.UI.UserControl
{
    private Osoba osoba = null;
    private Zamestnanie zamestanie = null;

    public Osoba Data
    {
        get { return osoba; }
        set { osoba = value; }
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        HideStatus();

        ODS_Jobs.SelectParameters["osobaId"].DefaultValue = osoba.Id.ToString();
    }

    protected override void OnPreRender(EventArgs e)
    {
        base.OnPreRender(e);

        if ( GV_Jobs.SelectedValue == null ) BN_Edit.Visible = false;
        else BN_Edit.Visible = true;
    }

    private void ShowError( string text )
    {
        LA_Status.ForeColor = System.Drawing.Color.Red;
        LA_Status.Text = text;
        LA_Status.Visible = true;
    }

    private void HideStatus()
    {
        LA_Status.Visible = false;
    }

    private void ShowSuccess( string text )
    {
        LA_Status.ForeColor = System.Drawing.Color.Green;
        LA_Status.Text = text;
        LA_Status.Visible = true;
    }

    private void SetFields( Zamestnanie zamestanie )
    {
        PoziciaOdvetvie poziciaOdvetvie = PoziciaOdvetvieDAL.SelectById( zamestanie.PoziciaOdvetvieId.Value );

        DDL_Sector.SelectedItem.Selected = false;
        
        DDL_Sector.Items.FindByValue( OdvetvieDAL.SelectById( poziciaOdvetvie.OdvetvieId ).Id.ToString() ).Selected = true;

        DDL_Sector_SelectedIndexChanged( this, null );

        DDL_Position.SelectedItem.Selected = false;

        DDL_Position.Items.FindByValue( poziciaOdvetvie.Id.ToString() ).Selected = true;

        TB_Employer.Text = zamestanie.NazovFirmy;
        TB_Finished.Text = zamestanie.DatumDo.HasValue ? zamestanie.DatumDo.Value.ToShortDateString().Replace(" ","") : null;
        TB_Note.Text = zamestanie.Poznamka;
        TB_Started.Text = zamestanie.DatumOd.ToShortDateString().Replace(" ", ""); 
    }
   
    private void ClearFields()
    {
        DDL_Sector.SelectedIndex = 0;

        DDL_Sector_SelectedIndexChanged( this, null );

        TB_Employer.Text = null;
        TB_Finished.Text = null;
        TB_Note.Text = null;
        TB_Started.Text = null; 
    }

    protected void BN_Insert_Click(object sender, EventArgs e)
    {
        HideStatus();

        zamestanie = new Zamestnanie();

        zamestanie.OsobaId = osoba.Id;
        if( TB_Finished.Text.Trim() == string.Empty ) zamestanie.DatumDo = null;
        else zamestanie.DatumDo = DateTime.Parse( TB_Finished.Text );
        zamestanie.DatumOd = DateTime.Parse( TB_Started.Text );
        zamestanie.NazovFirmy = TB_Employer.Text;
        zamestanie.PoziciaOdvetvieId = Convert.ToInt32( DDL_Position.SelectedValue );
        zamestanie.Poznamka = TB_Note.Text;

        if( zamestanie.DatumDo == null ) ZamestnanieDAL.Insert( zamestanie );
        else
        {
            if( zamestanie.DatumOd > zamestanie.DatumDo ) 
            {
                ShowError("Nesprvne zadan dtumy!");
                return;
            }
            else ZamestnanieDAL.Insert( zamestanie );
        }

        ClearFields();

        GV_Jobs.SelectedIndex = -1;

        ShowSuccess("Zamestanie bolo pridan");
    }
    protected void BN_Edit_Click(object sender, EventArgs e)
    {
        HideStatus();

        zamestanie = ZamestnanieDAL.SelectById( (int)GV_Jobs.SelectedValue );

        zamestanie.OsobaId = osoba.Id;
        if( TB_Finished.Text.Trim() == string.Empty ) zamestanie.DatumDo = null;
        else zamestanie.DatumDo = DateTime.Parse( TB_Finished.Text );
        zamestanie.DatumOd = DateTime.Parse( TB_Started.Text );
        zamestanie.NazovFirmy = TB_Employer.Text;
        zamestanie.PoziciaOdvetvieId = Convert.ToInt32( DDL_Position.SelectedValue );
        zamestanie.Poznamka = TB_Note.Text;

        if( zamestanie.DatumDo == null ) ZamestnanieDAL.Update( zamestanie );
        else
        {
            if( zamestanie.DatumOd >= zamestanie.DatumDo ) 
            {
                ShowError("Nesprvne zadan dtumy!");
                return;
            }
            else ZamestnanieDAL.Update( zamestanie );
        }

        ClearFields();

        GV_Jobs.SelectedIndex = -1;

        ShowSuccess("Zamestanie bolo upraven");
    }
    protected void BN_New_Click(object sender, EventArgs e)
    {
        ClearFields();

        GV_Jobs.SelectedIndex = -1;
    }
    protected void GV_Jobs_RowSelecting(object sender, GridViewSelectEventArgs e)
    {
        int id = Convert.ToInt32( GV_Jobs.DataKeys[e.NewSelectedIndex].Value );

        zamestanie = ZamestnanieDAL.SelectById( id );

        SetFields( zamestanie );
    }

    protected void GV_Jobs_RowDeleting(object sender, GridViewDeleteEventArgs e)
    {
        ShowSuccess("Zamestanie bolo zmazan");
    }

    protected void DDL_Sector_SelectedIndexChanged(object sender, EventArgs e)
    {
        List<PoziciaOdvetvie> poziciaOdvetvieList = PoziciaOdvetvieDAL.SelectByOdvetiveId( Convert.ToInt32( DDL_Sector.SelectedValue ) );

        DDL_Position.Items.Clear();

        foreach ( PoziciaOdvetvie poziciaOdvetvie in poziciaOdvetvieList )
        {
            DDL_Position.Items.Add( new ListItem( poziciaOdvetvie.Pozicia, poziciaOdvetvie.Id.ToString() ) );
        }

        DDL_Position.SelectedIndex = 0;
    }
    protected void DDL_Sector_DataBound(object sender, EventArgs e)
    {
        DDL_Sector.SelectedIndex = 0;

        DDL_Sector_SelectedIndexChanged( this, null );
    }
}
