using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Collections.Generic;

public partial class EditLanguagesUC : System.Web.UI.UserControl
{
    private Osoba osoba = null;
    private Jazyk jazyk = null;

    public Osoba Data
    {
        get { return osoba; }
        set { osoba = value; }
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        HideStatus();

        ODS_Languages.SelectParameters["osobaId"].DefaultValue = osoba.Id.ToString();

        if ( !Page.IsPostBack )
        {
            List<JazykHodnotenie> rates = JazykHodnotenieDAL.Select();

            SetDropDownList( DDL_Interaction, rates );
            SetDropDownList( DDL_Listening, rates );
            SetDropDownList( DDL_Reading, rates );
            SetDropDownList( DDL_Speach, rates );
            SetDropDownList( DDL_Writing, rates );
        }
    }

    protected override void OnPreRender(EventArgs e)
    {
        base.OnPreRender(e);

        if ( GV_Languages.SelectedValue == null ) BN_Edit.Visible = false;
        else BN_Edit.Visible = true;
    }

    private void ShowError(string text)
    {
        LA_Status.ForeColor = System.Drawing.Color.Red;
        LA_Status.Text = text;
        LA_Status.Visible = true;
    }

    private void HideStatus()
    {
        LA_Status.Visible = false;
    }

    private void ShowSuccess(string text)
    {
        LA_Status.ForeColor = System.Drawing.Color.Green;
        LA_Status.Text = text;
        LA_Status.Visible = true;
    }

    private void SetFields( Jazyk jazyk )
    {
        DDL_Interaction.SelectedItem.Selected = false;
        DDL_Listening.SelectedItem.Selected = false;
        DDL_Reading.SelectedItem.Selected = false;
        DDL_Speach.SelectedItem.Selected = false;
        DDL_Writing.SelectedItem.Selected = false;

        TB_Language.Text = jazyk.Nazov;
        DDL_Interaction.Items.FindByValue( jazyk.HovorenieInterakcia.ToString() ).Selected = true;
        DDL_Listening.Items.FindByValue( jazyk.PorozumeniePocuvanie.ToString() ).Selected = true;
        DDL_Reading.Items.FindByValue( jazyk.PorozumenieCitanie.ToString() ).Selected = true;
        DDL_Speach.Items.FindByValue( jazyk.HovoreniePrejav.ToString() ).Selected = true;
        DDL_Writing.Items.FindByValue( jazyk.Pisanie.ToString() ).Selected = true;
    }
   
    private void SetDropDownList( DropDownList dropDownList, List<JazykHodnotenie> rateList )
    {
        dropDownList.Items.Clear();

        foreach( JazykHodnotenie rate in rateList )
        {
            dropDownList.Items.Add( new ListItem( rate.HodnotenieSkupina + " " + rate.HodnoteniePopis, rate.Id.ToString() ) );
        }
    }

    private void ClearFields()
    {
        TB_Language = null;
        DDL_Interaction.SelectedIndex = 0;
        DDL_Listening.SelectedIndex = 0;
        DDL_Reading.SelectedIndex = 0;
        DDL_Speach.SelectedIndex = 0;
        DDL_Writing.SelectedIndex = 0;
    }

    protected void BN_Insert_Click(object sender, EventArgs e)
    {
        HideStatus();

        jazyk = new Jazyk();

        jazyk.OsobaId = osoba.Id;
        jazyk.Nazov = TB_Language.Text;
        jazyk.HovorenieInterakcia = Convert.ToInt32( DDL_Interaction.SelectedValue );
        jazyk.HovoreniePrejav = Convert.ToInt32( DDL_Speach.SelectedValue );
        jazyk.Pisanie = Convert.ToInt32( DDL_Writing.SelectedValue );
        jazyk.PorozumenieCitanie = Convert.ToInt32( DDL_Reading.SelectedValue );
        jazyk.PorozumeniePocuvanie = Convert.ToInt32( DDL_Listening.SelectedValue );

        JazykDAL.Insert( jazyk );

        ClearFields();

        GV_Languages.SelectedIndex = -1;

        ShowSuccess("Jazyk bol pridan");
    }

    protected void BN_Edit_Click(object sender, EventArgs e)
    {
        HideStatus();

        jazyk = JazykDAL.SelectById( (int)GV_Languages.SelectedValue );

        jazyk.OsobaId = osoba.Id;
        jazyk.Nazov = TB_Language.Text;
        jazyk.HovorenieInterakcia = Convert.ToInt32( DDL_Interaction.SelectedValue );
        jazyk.HovoreniePrejav = Convert.ToInt32( DDL_Speach.SelectedValue );
        jazyk.Pisanie = Convert.ToInt32( DDL_Writing.SelectedValue );
        jazyk.PorozumenieCitanie = Convert.ToInt32( DDL_Reading.SelectedValue );
        jazyk.PorozumeniePocuvanie = Convert.ToInt32( DDL_Listening.SelectedValue );

        JazykDAL.Update( jazyk );

        ClearFields();

        GV_Languages.SelectedIndex = -1;

        ShowSuccess("Jazyk bol upraven");
    }

    protected void BN_New_Click(object sender, EventArgs e)
    {
        ClearFields();

        GV_Languages.SelectedIndex = -1;
    }
    protected void GV_Languages_RowDeleted(object sender, GridViewDeletedEventArgs e)
    {
        ShowSuccess("Jazyk bol zmazan");
    }
    protected void GV_Languages_RowSelecting(object sender, GridViewSelectEventArgs e)
    {
        int id = Convert.ToInt32( GV_Languages.DataKeys[e.NewSelectedIndex].Value );

        jazyk = JazykDAL.SelectById( id );

        SetFields( jazyk );
    }
}
