using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

public partial class EditStudiesUC : System.Web.UI.UserControl
{
    private Osoba osoba = null;
    private Studium studium = null;

    public Osoba Data
    {
        get { return osoba; }
        set { osoba = value; }
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        HideStatus();

        ODS_Studies.SelectParameters["osobaId"].DefaultValue = osoba.Id.ToString();
    }

    protected override void OnPreRender(EventArgs e)
    {
        base.OnPreRender(e);

        if ( GV_Studies.SelectedValue == null ) BN_Edit.Visible = false;
        else BN_Edit.Visible = true;
    }


    private void ShowError( string text )
    {
        LA_Status.ForeColor = System.Drawing.Color.Red;
        LA_Status.Text = text;
        LA_Status.Visible = true;
    }

    private void HideStatus()
    {
        LA_Status.Visible = false;
    }

    private void ShowSuccess( string text )
    {
        LA_Status.ForeColor = System.Drawing.Color.Green;
        LA_Status.Text = text;
        LA_Status.Visible = true;
    }

    private void SetFields( Studium studium )
    {
        DDL_School.SelectedItem.Selected = false;
        
        DDL_School.Items.FindByValue( studium.SkolaId.ToString() ).Selected = true;

        DDL_Direction.SelectedItem.Selected = false;

        DDL_Direction.Items.FindByValue( studium.SmerId.ToString() ).Selected = true;

        TB_Faculty.Text = studium.Fakulta;
        TB_Finished.Text = studium.DatumDo.HasValue ? studium.DatumDo.Value.ToShortDateString().Replace(" ","") : null;
        TB_Odbor.Text = studium.Odbor;
        TB_Started.Text = studium.DatumOd.ToShortDateString().Replace(" ", ""); 
        TB_Title.Text = studium.ZiskanyTitul;
    }
   
    private void ClearFields()
    {
        DDL_School.SelectedIndex = 0;
        DDL_Direction.SelectedIndex = 0;

        TB_Faculty.Text = null;
        TB_Finished.Text = null;
        TB_Odbor.Text = null;
        TB_Started.Text = null;
        TB_Title.Text = null;
    }

    protected void BN_New_Click(object sender, EventArgs e)
    {
        ClearFields();

        GV_Studies.SelectedIndex = -1;
    }

    protected void BN_Insert_Click(object sender, EventArgs e)
    {
        HideStatus();

        studium = new Studium();

        if( TB_Finished.Text.Trim() == string.Empty ) studium.DatumDo = null;
        else studium.DatumDo = DateTime.Parse( TB_Finished.Text );
        studium.DatumOd = DateTime.Parse( TB_Started.Text );
        studium.Fakulta = TB_Faculty.Text;
        studium.OsobaId = osoba.Id;
        studium.Odbor= TB_Odbor.Text;
        studium.SkolaId = Convert.ToInt32( DDL_School.SelectedValue );
        studium.SmerId = Convert.ToInt32( DDL_Direction.SelectedValue );
        studium.ZiskanyTitul= TB_Title.Text;

        if( studium.DatumDo == null ) StudiumDAL.Insert( studium );
        else
        {
            if( studium.DatumOd >= studium.DatumDo ) 
            {
                ShowError("Nesprvne zadan dtumy!");
                return;
            }
            else StudiumDAL.Insert( studium );
        }

        ClearFields();

        GV_Studies.SelectedIndex = -1;

        ShowSuccess("tdium bolo pridan"); 
    }

    protected void BN_Edit_Click(object sender, EventArgs e)
    {
        HideStatus();

        studium = StudiumDAL.SelectById( (int)GV_Studies.SelectedValue );

        if( TB_Finished.Text.Trim() == string.Empty ) studium.DatumDo = null;
        else studium.DatumDo = DateTime.Parse( TB_Finished.Text );
        studium.DatumOd = DateTime.Parse( TB_Started.Text );
        studium.Fakulta = TB_Faculty.Text;
        studium.OsobaId = osoba.Id;
        studium.Odbor= TB_Odbor.Text;
        studium.SkolaId = Convert.ToInt32( DDL_School.SelectedValue );
        studium.SmerId = Convert.ToInt32( DDL_Direction.SelectedValue );
        studium.ZiskanyTitul= TB_Title.Text;

        if( studium.DatumDo == null ) StudiumDAL.Insert( studium );
        else
        {
            if( studium.DatumOd >= studium.DatumDo ) 
            {
                ShowError("Nesprvne zadan dtumy!");
                return;
            }
            else StudiumDAL.Update( studium );
        }

        ClearFields();

        GV_Studies.SelectedIndex = -1;

        ShowSuccess("tdium bolo upraven"); 
    }

    protected void GV_Studies_RowSelecting(object sender, GridViewSelectEventArgs e)
    {
        int id = Convert.ToInt32( GV_Studies.DataKeys[e.NewSelectedIndex].Value );

        studium = StudiumDAL.SelectById( id );

        SetFields( studium );
    }

    protected void GV_Studies_RowDeleting(object sender, GridViewDeleteEventArgs e)
    {
        ShowSuccess("tdium bolo zmazan");
    }

}
