﻿SET search_path = alumni;
SET default_tablespace = '';
SET default_with_oids = false;


DROP TABLE IF EXISTS adresa;
DROP TABLE IF EXISTS anketa;
DROP TABLE IF EXISTS instancia_ankety;
DROP TABLE IF EXISTS jazyk;
DROP TABLE IF EXISTS jazyk_hodnotenie;
DROP TABLE IF EXISTS kurz;
DROP TABLE IF EXISTS mozne_odpovede;
DROP TABLE IF EXISTS odpoved;
DROP TABLE IF EXISTS odvetvie;
DROP TABLE IF EXISTS obmedzenie;
DROP TABLE IF EXISTS operacia;
DROP TABLE IF EXISTS osoba CASCADE;
DROP TABLE IF EXISTS otazka;
DROP TABLE IF EXISTS oznam;
DROP TABLE IF EXISTS pozicia_odvetvie;
DROP TABLE IF EXISTS prispevok;
DROP TABLE IF EXISTS projekt;
DROP TABLE IF EXISTS registracia;
DROP TABLE IF EXISTS skola;
DROP TABLE IF EXISTS smer;
DROP TABLE IF EXISTS blacklist_sprava CASCADE;
DROP TABLE IF EXISTS typ_spravy CASCADE;
DROP TABLE IF EXISTS sprava CASCADE;
DROP TABLE IF EXISTS skupinova_sprava;
DROP TABLE IF EXISTS stat;
DROP TABLE IF EXISTS studium;
DROP TABLE IF EXISTS tema;
DROP TABLE IF EXISTS typ_osoby;
DROP TABLE IF EXISTS typ_oznamu;
DROP TABLE IF EXISTS typ_registracie;
DROP TABLE IF EXISTS zamestnanie;


CREATE TABLE adresa (
    id serial NOT NULL UNIQUE,
    osoba_id integer,
    zamestnanie_id integer,
    ulica text NOT NULL,
    psc character varying(10) NOT NULL,
    mesto character varying(50) NOT NULL,
    stat_id integer NOT NULL,
    CONSTRAINT adresa_pkey PRIMARY KEY (id)
);

CREATE TABLE anketa (
    id serial NOT NULL UNIQUE,
    nazov character varying(100) NOT NULL,
    mozno_upravit boolean DEFAULT true NOT NULL,
    CONSTRAINT anketa_pkey PRIMARY KEY (id)
);

CREATE TABLE instancia_ankety (
    id serial NOT NULL UNIQUE,
    anketa_id integer NOT NULL,
    datum_od date NOT NULL,
    datum_do date NOT NULL,
    CONSTRAINT instancia_ankety_pkey PRIMARY KEY (id)
);

CREATE TABLE jazyk (
    id serial NOT NULL UNIQUE,
    osoba_id integer NOT NULL,
    porozumenie_pocuvanie integer DEFAULT 0 NOT NULL,
    porozumenie_citanie integer DEFAULT 0 NOT NULL,
    hovorenie_interakcia integer DEFAULT 0 NOT NULL,
    hovorenie_prejav integer DEFAULT 0 NOT NULL,
    pisanie integer DEFAULT 0 NOT NULL,
    nazov character varying(30) NOT NULL,
    CONSTRAINT jazyk_pkey PRIMARY KEY (id)
);

CREATE TABLE jazyk_hodnotenie (
    id serial NOT NULL UNIQUE,
    hodnotenie_skupina character(2) NOT NULL,
    hodnotenie_popis text,
    CONSTRAINT jazyk_hodnotenie_pkey PRIMARY KEY (id)
);

CREATE TABLE kurz (
    id serial NOT NULL UNIQUE,
    nazov character varying(100) NOT NULL,
    datum_od date,
    datum_do date,
    poznamka text,
    osoba_id integer NOT NULL,
    CONSTRAINT kurz_pkey PRIMARY KEY (id)
);

CREATE TABLE mozne_odpovede (
    id serial NOT NULL UNIQUE,
    text text NOT NULL,
    otazka_id integer NOT NULL,
    CONSTRAINT mozne_odpovede_pkey PRIMARY KEY (id)
);

CREATE TABLE obmedzenie (
    id serial NOT NULL UNIQUE,
    typ_osoby_id integer NOT NULL,
    operacia_id integer NOT NULL,
    objekt_obmedzenia integer NOT NULL,
    CONSTRAINT obmedzenie_pkey PRIMARY KEY (id)
);

CREATE TABLE odpoved (
    id serial NOT NULL UNIQUE,
    instancia_ankety_id integer NOT NULL,
    osoba_id integer NOT NULL,
    otazka_id integer NOT NULL,
    text_odpovede text NOT NULL,
    CONSTRAINT odpoved_pkey PRIMARY KEY (id)
);

CREATE TABLE odvetvie (
    id serial NOT NULL UNIQUE,
    nazov character varying(50) NOT NULL,
    CONSTRAINT odvetvie_pkey PRIMARY KEY (id)
);

CREATE TABLE operacia (
    id serial NOT NULL UNIQUE,
    nazov character varying(20) NOT NULL,
    CONSTRAINT operacia_pkey PRIMARY KEY (id)
);

CREATE TABLE osoba (
    id serial NOT NULL UNIQUE,
    typ_osoby_id integer NOT NULL,
    konto character varying(20) NOT NULL UNIQUE,
    konto_aktivne boolean DEFAULT true NOT NULL,
    heslo character varying(512) NOT NULL,
    posledne_prihlasenie timestamp,
    posledna_ip inet,
    meno character varying(20) NOT NULL,
    tituly character varying(20),
    priezvisko character varying(20) NOT NULL,
    rodne_priezvisko character varying(20),
    statna_prislusnost character varying(20),
    materinsky_jazyk character varying(20),
    telefon character varying(20),
    mobil character varying(20),
    fax character varying(20),
    msn character varying(50),
    email character varying(50) NOT NULL UNIQUE,
    web text,
    pohlavie character varying(4),
    datum_narodenia date NOT NULL,
    rok_absolvovania integer,
    zivotopis_ine text,
    icq character varying(10),
    skype text,
    --fotografia bytea,
    socialne_zrucnosti text,
    organizacne_zrucnosti text,
    technicke_zrucnosti text,
    pocitacove_zrucnosti text,
    umelecke_zrucnosti text,
    dalsie_zrucnosti text,
    vodicsky_preukaz character varying(50),
    CONSTRAINT osoba_pkey PRIMARY KEY (id)
);

CREATE TABLE otazka (
    id serial NOT NULL UNIQUE,
    text_otazky text NOT NULL,
    typ_odpovede smallint NOT NULL,
    ine character varying(50),
    anketa_id integer NOT NULL,
    CONSTRAINT otazka_pkey PRIMARY KEY (id)
);

CREATE TABLE oznam (
    id serial NOT NULL UNIQUE,
    osoba_id integer NOT NULL,
    nazov character varying(100) NOT NULL,
    datum_platnosti date NOT NULL,
    typ_oznamu_id integer NOT NULL,
    popis text NOT NULL,
    CONSTRAINT oznam_pkey PRIMARY KEY (id)
);

CREATE TABLE pozicia_odvetvie (
    id serial NOT NULL UNIQUE,
    pozicia character varying(50) NOT NULL,
    odvetvie_id integer DEFAULT 0 NOT NULL,
    CONSTRAINT pozicia_odvetvie_pkey PRIMARY KEY (id)
);

CREATE TABLE prispevok (
    id serial NOT NULL UNIQUE,
    text text NOT NULL,
    cas timestamp with time zone NOT NULL,
    tema_id integer NOT NULL,
    osoba_id integer NOT NULL,
    predmet character varying(100),
    CONSTRAINT prispevok_pkey PRIMARY KEY (id)
);

CREATE TABLE projekt (
    id serial NOT NULL UNIQUE,
    osoba_id integer NOT NULL,
    job_id integer,
    studium_id integer,
    nazov character varying(100) NOT NULL,
    abstrakt text,
    veduci character varying(50),
    klucove_slova text NOT NULL,
    datum_vypracovania date NOT NULL,
    www_odkaz text,
    poznamka text,
    CONSTRAINT projekt_pkey PRIMARY KEY (id)
);

CREATE TABLE registracia (
    id serial NOT NULL UNIQUE,
    email character varying(50) NOT NULL UNIQUE,
    heslo character varying(512) NOT NULL,
    meno character varying(20) NOT NULL,
    priezvisko character varying(20) NOT NULL,
    datum_narodenia date NOT NULL,
    rok_absolvovania integer,
    typ_registracie_id integer NOT NULL,
    CONSTRAINT registracia_pkey PRIMARY KEY (id)
);

CREATE TABLE skola (
    id serial NOT NULL UNIQUE,
    nazov character varying(255) NOT NULL,
    CONSTRAINT skola_pkey PRIMARY KEY (id)
);

CREATE TABLE smer (
    id serial NOT NULL UNIQUE,
    nazov character varying(50) NOT NULL,
    CONSTRAINT smer_pkey PRIMARY KEY (id)
);

CREATE TABLE blacklist_sprava
(
  id serial NOT NULL UNIQUE,
  odosielatel_konto character varying(20) NOT NULL,
  prijemca_id integer NOT NULL,
  is_skupina boolean NOT NULL DEFAULT false,
  CONSTRAINT blacklist_sprava_pkey PRIMARY KEY (id),
  CONSTRAINT blacklist_sprava_prijemca_id_fkey FOREIGN KEY (prijemca_id)
      REFERENCES alumni.osoba (id) MATCH SIMPLE
      ON UPDATE CASCADE ON DELETE CASCADE,
  CONSTRAINT blacklist_sprava_odosielatel_id_key UNIQUE (odosielatel_konto, prijemca_id, is_skupina)
);

CREATE TABLE typ_spravy
(
  id serial NOT NULL UNIQUE,
  typ character varying(20) NOT NULL,
  CONSTRAINT typ_spravy_pkey PRIMARY KEY (id)
);

CREATE TABLE sprava
(
  id serial NOT NULL UNIQUE,
  odosielatel_id integer NOT NULL,
  prijemca_id integer NOT NULL,
  cas timestamp with time zone NOT NULL,
  predmet character varying(100),
  text text,
  precitana boolean NOT NULL DEFAULT false,
  odosielatel_kos boolean NOT NULL DEFAULT false,
  prijemca_kos boolean NOT NULL DEFAULT false,
  odosielatel_zmazana boolean NOT NULL DEFAULT false,
  prijemca_zmazana boolean NOT NULL DEFAULT false,
  notifikovat boolean NOT NULL DEFAULT true,
  typ_spravy_id integer NOT NULL DEFAULT 1,
  CONSTRAINT sprava_pkey PRIMARY KEY (id),
  CONSTRAINT sprava_typ_spravy_id_fkey FOREIGN KEY (typ_spravy_id)
      REFERENCES alumni.typ_spravy (id) MATCH SIMPLE
      ON UPDATE CASCADE ON DELETE SET DEFAULT
);

CREATE TABLE skupinova_sprava
(
-- Inherited:   id integer NOT NULL DEFAULT nextval('alumni.sprava_id_seq'::regclass),
-- Inherited:   odosielatel_id integer NOT NULL,
-- Inherited:   prijemca_id integer NOT NULL,
-- Inherited:   cas timestamp with time zone NOT NULL,
-- Inherited:   predmet character varying(100),
-- Inherited:   text text,
-- Inherited:   precitana boolean NOT NULL DEFAULT false,
-- Inherited:   odosielatel_kos boolean NOT NULL DEFAULT false,
-- Inherited:   prijemca_kos boolean NOT NULL DEFAULT false,
-- Inherited:   odosielatel_zmazana boolean NOT NULL DEFAULT false,
-- Inherited:   prijemca_zmazana boolean NOT NULL DEFAULT false,
-- Inherited:   notifikovat boolean NOT NULL DEFAULT true,
-- Inherited:   typ_spravy_id integer NOT NULL DEFAULT 1,
  prijemca_skup character varying(50) NOT NULL
) INHERITS (sprava);

CREATE TABLE stat (
    id serial NOT NULL UNIQUE,
    nazov character varying(50) NOT NULL,
    CONSTRAINT stat_pkey PRIMARY KEY (id)
);

CREATE TABLE studium (
    id serial NOT NULL UNIQUE,
    osoba_id integer NOT NULL,
    skola_id integer NOT NULL,
    smer_id integer,
    stupen numeric(1,0) DEFAULT 1 NOT NULL,
    osobne_cislo numeric(15,0),
    datum_od date,
    datum_do date,
    prospech numeric(2,2),
    fakulta character varying(100),
    odbor character varying(50),
    typ_skoly numeric(2,0),
    ziskany_titul character varying(10),
    CONSTRAINT studium_pkey PRIMARY KEY (id)
);

CREATE TABLE tema (
    id serial NOT NULL UNIQUE,
    nazov character varying(100) NOT NULL,
    popis text,
    cas timestamp with time zone NOT NULL,
    je_verejna boolean DEFAULT true NOT NULL,
    osoba_id integer NOT NULL,
    nadtema integer,
    CONSTRAINT tema_pkey PRIMARY KEY (id)
);

CREATE TABLE typ_osoby (
    id serial NOT NULL UNIQUE,
    typ character varying(20) NOT NULL,
    CONSTRAINT typ_osoby_pkey PRIMARY KEY (id)
);

CREATE TABLE typ_oznamu (
    id serial NOT NULL UNIQUE,
    typ character varying(50) NOT NULL,
    CONSTRAINT typ_oznamu_pkey PRIMARY KEY (id)
);

CREATE TABLE typ_registracie (
    id serial NOT NULL UNIQUE,
    typ character varying(30) NOT NULL,
    CONSTRAINT typ_registracie_pkey PRIMARY KEY (id)
);

CREATE TABLE zamestnanie (
    id serial NOT NULL UNIQUE,
    osoba_id integer NOT NULL,
    pozicia_odvetvie_id integer,
    datum_od date NOT NULL,
    datum_do date,
    nazov_firmy character varying(50) NOT NULL,
    poznamka text,
    CONSTRAINT zamestnanie_pkey PRIMARY KEY (id)
);


INSERT INTO osoba(
            typ_osoby_id, konto, konto_aktivne, heslo, posledne_prihlasenie, 
            posledna_ip, meno, priezvisko, telefon, email, web, pohlavie, 
            datum_narodenia )
     VALUES ( 4, 'admin', true, 'Pp+OaSS0MPzhKJ4i6oJ4ROEt6zynmHNEZ1/X1QNVqnrCV7AnG0El+vbLYC2xPmeg9YK7qqRLHy95PTw9tInmflPa6/sp8IKldkgyXyz2/yA=', now(), '127.0.0.1', 
            'Admin', 'Admin', '123456789', 'admin@pobox.sk', 'www.mojweb.sk', 'muz', '01-Jan-2000' );

INSERT INTO osoba(
            typ_osoby_id, konto, konto_aktivne, heslo, posledne_prihlasenie, 
            posledna_ip, meno, priezvisko, telefon, email, web, pohlavie, 
            datum_narodenia )
     VALUES ( 3, 'fakultnik', true, 'Pp+OaSS0MPzhKJ4i6oJ4ROEt6zynmHNEZ1/X1QNVqnrCV7AnG0El+vbLYC2xPmeg9YK7qqRLHy95PTw9tInmflPa6/sp8IKldkgyXyz2/yA=', now(), '127.0.0.1', 
            'Fakultnik', 'Fakultnik', '123456789', 'fakultnik@pobox.sk', 'www.mojweb.sk', 'muz', '01-Jan-2000' );

INSERT INTO osoba(
            typ_osoby_id, konto, konto_aktivne, heslo, posledne_prihlasenie, 
            posledna_ip, meno, priezvisko, telefon, email, web, pohlavie, 
            datum_narodenia )
     VALUES ( 2, 'absolvent', true, 'Pp+OaSS0MPzhKJ4i6oJ4ROEt6zynmHNEZ1/X1QNVqnrCV7AnG0El+vbLYC2xPmeg9YK7qqRLHy95PTw9tInmflPa6/sp8IKldkgyXyz2/yA=', now(), '127.0.0.1', 
            'Absolvent', 'Absolvent', '123456789', 'absolvent@pobox.sk', 'www.mojweb.sk', 'muz', '01-Jan-2000' );

INSERT INTO osoba(
            typ_osoby_id, konto, konto_aktivne, heslo, posledne_prihlasenie, 
            posledna_ip, meno, priezvisko, telefon, email, web, pohlavie, 
            datum_narodenia )
     VALUES ( 1, 'student', true, 'Pp+OaSS0MPzhKJ4i6oJ4ROEt6zynmHNEZ1/X1QNVqnrCV7AnG0El+vbLYC2xPmeg9YK7qqRLHy95PTw9tInmflPa6/sp8IKldkgyXyz2/yA=', now(), '127.0.0.1', 
            'Student', 'Student', '123456789', 'student@pobox.sk', 'www.mojweb.sk', 'muz', '01-Jan-2000' );

INSERT INTO stat(nazov) VALUES ('Slovenská Republika');

INSERT INTO typ_osoby(typ) VALUES ('Študent');
INSERT INTO typ_osoby(typ) VALUES ('Absolvent');
INSERT INTO typ_osoby(typ) VALUES ('Fakultník');
INSERT INTO typ_osoby(typ) VALUES ('Administrátor');

INSERT INTO typ_registracie(typ) VALUES ('Nová registrácia');
INSERT INTO typ_registracie(typ) VALUES ('Obnovenie účtu');

INSERT INTO stat(nazov) VALUES ('Slovensko');
INSERT INTO stat(nazov) VALUES ('Poľsko');
INSERT INTO stat(nazov) VALUES ('Ukrajina');
INSERT INTO stat(nazov) VALUES ('Nemecko');

INSERT INTO odvetvie(nazov) VALUES ('Informatika');
INSERT INTO odvetvie(nazov) VALUES ('Softvérový inžinierstvo');

INSERT INTO pozicia_odvetvie(pozicia,odvetvie_id) VALUES ('Systémový administrátor',1);
INSERT INTO pozicia_odvetvie(pozicia,odvetvie_id) VALUES ('Databázový expert',1);
INSERT INTO pozicia_odvetvie(pozicia,odvetvie_id) VALUES ('Programátor',2);
INSERT INTO pozicia_odvetvie(pozicia,odvetvie_id) VALUES ('Analytik',2);

INSERT INTO jazyk_hodnotenie(hodnotenie_skupina,hodnotenie_popis) VALUES ('A1','Používateľ základného jazyka');
INSERT INTO jazyk_hodnotenie(hodnotenie_skupina,hodnotenie_popis) VALUES ('A2','Používateľ základného jazyka');
INSERT INTO jazyk_hodnotenie(hodnotenie_skupina,hodnotenie_popis) VALUES ('B1','Samostatný používateľ');
INSERT INTO jazyk_hodnotenie(hodnotenie_skupina,hodnotenie_popis) VALUES ('B2','Samostatný používateľ');
INSERT INTO jazyk_hodnotenie(hodnotenie_skupina,hodnotenie_popis) VALUES ('C1','Skúsený používateľ');
INSERT INTO jazyk_hodnotenie(hodnotenie_skupina,hodnotenie_popis) VALUES ('C2','Skúsený používateľ');

INSERT INTO typ_spravy (id, typ) VALUES (1, 'Normálna');
INSERT INTO typ_spravy (id, typ) VALUES (2, 'Skupinová');

INSERT INTO alumni.typ_oznamu(typ) VALUES ('typ1');
INSERT INTO alumni.typ_oznamu(typ) VALUES ('typ2');