using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

public partial class ProfessionProfile : System.Web.UI.Page
{
    private int id;
    private Osoba osoba;
    private PlaceHolder jobsPlaceHolder;
    private PlaceHolder coursesPlaceHolder;
    private PlaceHolder languagesPlaceHolder;
    private PlaceHolder studiesPlaceHolder;


    protected void Page_Load(object sender, EventArgs e)
    {
        if ( ( id = Helper.QStringToInt32(Request["Id"]) ) != 0 )
        {
            osoba = OsobaDAL.SelectById(id);

            if ( osoba == null )
            {
                if ( User != null && User.Identity.IsAuthenticated ) osoba = OsobaDAL.SelectById( ((CustomPrincipal)User).Id );
                else { FormsAuthentication.RedirectToLoginPage(); return; }
            }
        }
        else
        {
            if ( User != null && User.Identity.IsAuthenticated ) osoba = OsobaDAL.SelectById( ((CustomPrincipal)User).Id );
            else { FormsAuthentication.RedirectToLoginPage(); return; }
        }

        jobsPlaceHolder = (PlaceHolder)MV_Profile.FindControl("PH_Jobs");
        coursesPlaceHolder = (PlaceHolder)MV_Profile.FindControl("PH_Courses");
        languagesPlaceHolder = (PlaceHolder)MV_Profile.FindControl("PH_Languages");
        studiesPlaceHolder = (PlaceHolder)MV_Profile.FindControl("PH_Studies");

        bool canEdit = CanEdit();

        InsertJobs( canEdit );
        InsertCourses( canEdit );
        InsertLanguages( canEdit );
        InsertStudies( canEdit );
    }

    protected void MN_Tabs_MenuItemClick(object sender, MenuEventArgs e)
    {
        MV_Profile.ActiveViewIndex = Convert.ToInt32( e.Item.Value );
    }

    private bool CanEdit() 
    {
        if( User != null && User.Identity.IsAuthenticated )
        {
            if( User.IsInRole("Administrtor") ) 
            {
                return true;
            }

            if( ((CustomPrincipal)User).Id == osoba.Id ) 
            {
                return true;
            }

            if( User.IsInRole("Fakultnk") ) 
            {
                return false;
            }

            FormsAuthentication.RedirectToLoginPage();
            return false;
        }

        return false;
    }

    public void InsertJobs( bool edit )
    {
        if( edit )
        {
            EditJobsUC editJobs = (EditJobsUC)LoadControl("~/Controls/EditJobsUC.ascx");
            editJobs.ID = "UC_EJ_Jobs";
            editJobs.Data = osoba;
            jobsPlaceHolder.Controls.Add( editJobs );
        }
        else
        {
            ViewJobsUC viewJobs = (ViewJobsUC)LoadControl("~/Controls/ViewJobsUC.ascx");
            viewJobs.ID = "UC_VJ_Jobs";
            viewJobs.Data = osoba;
            jobsPlaceHolder.Controls.Add(viewJobs);
        }
    }

    public void InsertCourses( bool edit )
    {
        if( edit )
        {
            EditCoursesUC editCourses = (EditCoursesUC)LoadControl("~/Controls/EditCoursesUC.ascx");
            editCourses.ID = "UC_EC_Courses";
            editCourses.Data = osoba;
            coursesPlaceHolder.Controls.Add( editCourses );
        }
        else
        {
            ViewCoursesUC viewCourses = (ViewCoursesUC)LoadControl("~/Controls/ViewCoursesUC.ascx");
            viewCourses.ID = "UC_VC_Courses";
            viewCourses.Data = osoba;
            coursesPlaceHolder.Controls.Add( viewCourses );
        }
    }

    public void InsertLanguages( bool edit )
    {
        if ( edit )
        {
            EditLanguagesUC editLanguages = (EditLanguagesUC)LoadControl("~/Controls/EditLanguagesUC.ascx");
            editLanguages.ID = "UC_EPI_Languages";
            editLanguages.Data = osoba;
            languagesPlaceHolder.Controls.Add( editLanguages );
        }
        else
        {
            ViewLanguagesUC viewLanguages = (ViewLanguagesUC)LoadControl("~/Controls/ViewLanguagesUC.ascx");
            viewLanguages.ID = "UC_VPI_Languages";
            viewLanguages.Data = osoba;
            languagesPlaceHolder.Controls.Add( viewLanguages );
        }
    }
    
    public void InsertStudies( bool edit )
    {
        if ( edit )
        {
            EditStudiesUC editStudies = (EditStudiesUC)LoadControl("~/Controls/EditStudiesUC.ascx");
            editStudies.ID = "UC_EPI_Studies";
            editStudies.Data = osoba;
            studiesPlaceHolder.Controls.Add( editStudies );
        }
        else
        {
            ViewStudiesUC viewStudies = (ViewStudiesUC)LoadControl("~/Controls/ViewStudiesUC.ascx");
            viewStudies.ID = "UC_VPI_Studies";
            viewStudies.Data = osoba;
            studiesPlaceHolder.Controls.Add( viewStudies );
        }
    }
}
