using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

public partial class UserProfile : System.Web.UI.Page
{
    private int id;
    private Osoba osoba;
    private PlaceHolder addressPlaceHolder;
    private PlaceHolder contactPlaceHolder;
    private PlaceHolder publicPlaceHolder;
    private PlaceHolder privatePlaceHolder;
    private PlaceHolder projectsPlaceHolder;
    private PlaceHolder passwordPlaceHolder;
    private PlaceHolder adminPlaceHolder;
    private MenuItemCollection menuItemList = new MenuItemCollection();

    protected void Page_Load(object sender, EventArgs e)
    {
        if ( ( id = Helper.QStringToInt32( Request["Id"] ) ) != 0 )
        {
            osoba = OsobaDAL.SelectById( id );

            if( osoba == null )
            {
                if( User != null && User.Identity.IsAuthenticated ) osoba = OsobaDAL.SelectById( ((CustomPrincipal)User).Id );
                else { FormsAuthentication.RedirectToLoginPage(); return; }
            }
        }
        else
        {
            if( User != null && User.Identity.IsAuthenticated ) osoba = OsobaDAL.SelectById( ((CustomPrincipal)User).Id );
            else { FormsAuthentication.RedirectToLoginPage(); return; }
        }

        addressPlaceHolder = (PlaceHolder)MV_Profile.FindControl("PH_Address");
        adminPlaceHolder = (PlaceHolder)MV_Profile.FindControl("PH_Admin");
        contactPlaceHolder = (PlaceHolder)MV_Profile.FindControl("PH_Contact");
        passwordPlaceHolder = (PlaceHolder)MV_Profile.FindControl("PH_Password");
        privatePlaceHolder = (PlaceHolder)MV_Profile.FindControl("PH_Private");
        projectsPlaceHolder = (PlaceHolder)MV_Profile.FindControl("PH_Projects");
        publicPlaceHolder = (PlaceHolder)MV_Profile.FindControl("PH_Public");

        MenuItem publicInfoMenuItem = new MenuItem("Verejn daje", "0");
        publicInfoMenuItem.Selected = true;

        menuItemList.Clear();
        MN_Tabs_Top.Items.Clear();
        MN_Tabs_Bottom.Items.Clear();

        menuItemList.Add( publicInfoMenuItem );

        bool canEdit = CanEdit();

        for( int i = 0; i < menuItemList.Count; i++ )
        {
            if( i < 5 )
            {
                MN_Tabs_Top.Items.Add( menuItemList[i] );
            }
            else
            {
                MN_Tabs_Bottom.Items.Add( menuItemList[i] );
            }
        }

        InsertPublicInfo( canEdit );
        InsertPrivateInfo( canEdit );
        InsertProjectsInfo( canEdit );
        InsertAddress( canEdit );
        InsertContact( canEdit );
        InsertChangePassword();
        InsertAdminProfile();
    }

    protected void MN_Tabs_MenuItemClick(object sender, MenuEventArgs e)
    {
        if( ((Menu)sender).ID == "MN_Tabs_Top" )
        {
            if ( MN_Tabs_Bottom.SelectedItem != null ) MN_Tabs_Bottom.SelectedItem.Selected = false;
        }
        else
        {
            if ( MN_Tabs_Top.SelectedItem != null ) MN_Tabs_Top.SelectedItem.Selected = false;
        }

        MV_Profile.ActiveViewIndex = Convert.ToInt32( e.Item.Value );
    }

    private bool CanEdit() 
    {
        if( User != null && User.Identity.IsAuthenticated )
        {
            if( User.IsInRole("Administrtor") ) 
            {
                menuItemList.Add( new MenuItem("Skromn daje", "1") );
                menuItemList.Add( new MenuItem("Adresa", "2") );
                menuItemList.Add( new MenuItem("Kontakt", "3") );
                if( ((CustomPrincipal)User).Id == osoba.Id ) menuItemList.Add( new MenuItem("Heslo", "4") );
                menuItemList.Add( new MenuItem("Projekty", "5") );
                menuItemList.Add( new MenuItem("Administrcia", "6") );

                return true;
            }

            if( ((CustomPrincipal)User).Id == osoba.Id ) 
            {
                menuItemList.Add( new MenuItem("Skromn daje", "1") );
                menuItemList.Add( new MenuItem("Adresa", "2") );
                menuItemList.Add( new MenuItem("Kontakt", "3") );
                menuItemList.Add( new MenuItem("Heslo", "4") );
                menuItemList.Add( new MenuItem("Projekty", "5") );

                return true;
            }
            else 
            {
                if( User.IsInRole("Fakultnk") ) 
                {
                    menuItemList.Add( new MenuItem("Skromn daje", "1") );
                    menuItemList.Add( new MenuItem("Adresa", "2") );
                    menuItemList.Add( new MenuItem("Kontakt", "3") );
                    menuItemList.Add( new MenuItem("Projekty", "5") );
                }

                return false;
            }
        }

        return false;
    }

    public void InsertAddress( bool edit )
    {
        if ( edit )
        {
            EditAddressUC editAddress = (EditAddressUC)LoadControl("~/Controls/EditAddressUC.ascx");
            editAddress.ID = "UC_EA_Address";
            editAddress.AdresaData = AdresaDAL.SelectByOsobaId( osoba.Id );
            editAddress.OsobaData = osoba;
            addressPlaceHolder.Controls.Add( editAddress );
        }
        else
        {
            ViewAddressUC viewAddress = (ViewAddressUC)LoadControl("~/Controls/ViewAddressUC.ascx");
            viewAddress.ID = "UC_VA_Address";
            viewAddress.Data = AdresaDAL.SelectByOsobaId( osoba.Id );
            addressPlaceHolder.Controls.Add( viewAddress );
        }
    }

    public void InsertAdminProfile()
    {
        AdminProfileUC adminProfile = (AdminProfileUC)LoadControl("~/Controls/AdminProfileUC.ascx");
        adminProfile.ID = "UC_CP_Admin";
        adminProfile.Data = osoba;
        adminPlaceHolder.Controls.Add( adminProfile );
    }

    public void InsertChangePassword()
    {
        ChangePasswordUC changePassword = (ChangePasswordUC)LoadControl("~/Controls/ChangePasswordUC.ascx");
        changePassword.ID = "UC_CP_Password";
        changePassword.Data = osoba;
        passwordPlaceHolder.Controls.Add( changePassword );
    }

    public void InsertContact( bool edit )
    {
        if( edit )
        {
            EditContactUC editContact = (EditContactUC)LoadControl("~/Controls/EditContactUC.ascx");
            editContact.ID = "UC_EC_Contact";
            editContact.Data = osoba;
            contactPlaceHolder.Controls.Add( editContact );
        }
        else
        {
            ViewContactUC viewContact = (ViewContactUC)LoadControl("~/Controls/ViewContactUC.ascx");
            viewContact.ID = "UC_VC_Contact";
            viewContact.Data = osoba;
            contactPlaceHolder.Controls.Add( viewContact );
        }
    }

    public void InsertPrivateInfo( bool edit )
    {
        if( edit )
        {
            EditPrivateInfoUC editPrivateInfo = (EditPrivateInfoUC)LoadControl("~/Controls/EditPrivateInfoUC.ascx");
            editPrivateInfo.ID = "UC_EPI_PrivateInfo";
            editPrivateInfo.Data = osoba;
            privatePlaceHolder.Controls.Add( editPrivateInfo );
        }
        else
        {
            ViewPrivateInfoUC viewPrivateInfo = (ViewPrivateInfoUC)LoadControl("~/Controls/ViewPrivateInfoUC.ascx");
            viewPrivateInfo.ID = "UC_VPI_PrivateInfo";
            viewPrivateInfo.Data = osoba;
            privatePlaceHolder.Controls.Add( viewPrivateInfo );
        }
    }

    public void InsertProjectsInfo( bool edit )
    {
        if( edit )
        {
            EditProjectListUC editProjectList = (EditProjectListUC)LoadControl("~/Controls/EditProjectListUC.ascx");
            editProjectList.ID = "UC_EPI_Projects";
            editProjectList.Data = osoba;
            projectsPlaceHolder.Controls.Add(editProjectList);
        }
        else
        {
            ViewProjectListUC viewProjectList = (ViewProjectListUC)LoadControl("~/Controls/ViewProjectListUC.ascx");
            viewProjectList.ID = "UC_VPI_Projects";
            viewProjectList.Data = osoba;
            projectsPlaceHolder.Controls.Add( viewProjectList );
        }
    }

    public void InsertPublicInfo( bool edit )
    {
        if ( edit )
        {
            EditPublicInfoUC editPublicInfo = (EditPublicInfoUC)LoadControl("~/Controls/EditPublicInfoUC.ascx");
            editPublicInfo.ID = "UC_EPI_PublicInfo";
            editPublicInfo.Data = osoba;
            publicPlaceHolder.Controls.Add( editPublicInfo );
        }
        else
        {
            ViewPublicInfoUC viewPublicInfo = (ViewPublicInfoUC)LoadControl("~/Controls/ViewPublicInfoUC.ascx");
            viewPublicInfo.ID = "UC_VPI_PublicInfo";
            viewPublicInfo.Data = osoba;
            publicPlaceHolder.Controls.Add( viewPublicInfo );
        }
    }
}
